<?php
// admin/component-create.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

try {
   // Инициализируем подключение к базе данных
   $db = new PDO(
       "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
       DB_USER,
       DB_PASS,
       array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
   );

   // Инициализируем AuthManager
   $authManager = new AuthManager($db);

   // Проверяем авторизацию
   if (!$authManager->isAuthenticated()) {
       header('Location: login.php');
       exit;
   }

   // Получаем текущего пользователя
   $currentUser = $authManager->getCurrentUser();

   // Получаем site_id из GET параметра
   $siteId = isset($_GET['site_id']) ? (int)$_GET['site_id'] : null;
   
   if (!$siteId) {
       $_SESSION['notification'] = [
           'type' => 'danger',
           'message' => 'Site ID is required'
       ];
       header('Location: components.php');
       exit;
   }

   // Получаем информацию о сайте
   $siteStmt = $db->prepare("SELECT id, domain, title FROM sites WHERE id = :id");
   $siteStmt->bindValue(':id', $siteId, PDO::PARAM_INT);
   $siteStmt->execute();
   $site = $siteStmt->fetch(PDO::FETCH_ASSOC);

   if (!$site) {
       $_SESSION['notification'] = [
           'type' => 'danger',
           'message' => 'Site not found'
       ];
       header('Location: sites.php');
       exit;
   }

   // Обработка формы создания компонента
   if ($_SERVER['REQUEST_METHOD'] === 'POST') {
       $name = trim($_POST['name'] ?? '');
       $type = $_POST['type'] ?? '';
       $content = $_POST['content'] ?? '';
       $isActive = isset($_POST['is_active']) ? 1 : 0;
       
       // Валидация
       $errors = [];
       if (empty($name)) {
           $errors[] = "Name is required";
       }
       
       $validTypes = ['header', 'footer', 'sidebar'];
       if (empty($type) || !in_array($type, $validTypes)) {
           $errors[] = "Valid component type is required";
       }
       
       if (empty($content)) {
           $errors[] = "Content is required";
       }
       
       if (empty($errors)) {
           // Добавляем новый компонент
           $stmt = $db->prepare("
               INSERT INTO components (site_id, name, type, content, is_active)
               VALUES (:site_id, :name, :type, :content, :is_active)
           ");
           
           $stmt->bindValue(':site_id', $siteId, PDO::PARAM_INT);
           $stmt->bindValue(':name', $name, PDO::PARAM_STR);
           $stmt->bindValue(':type', $type, PDO::PARAM_STR);
           $stmt->bindValue(':content', $content, PDO::PARAM_STR);
           $stmt->bindValue(':is_active', $isActive, PDO::PARAM_INT);
           $stmt->execute();
           
           $componentId = $db->lastInsertId();
           
           // Логируем создание
           $logger = new SystemLogger($db);
           $logger->log(
               $siteId,
               'component_created',
               "Component '{$name}' (type: {$type}) created by {$currentUser['username']}",
               'success'
           );
           
           $_SESSION['notification'] = [
               'type' => 'success',
               'message' => "Component '{$name}' has been successfully created"
           ];
           
           // Перенаправляем на страницу компонентов
           header('Location: components.php?site_id=' . $siteId);
           exit;
       }
   }
   
   // Шаблонный HTML в зависимости от типа (для автозаполнения)
   $templateHTML = [
       'header' => '<header class="site-header">
   <div class="container">
       <div class="row align-items-center">
           <div class="col-md-3">
               <div class="logo">
                   <a href="/">{site_name}</a>
               </div>
           </div>
           <div class="col-md-9">
               <nav class="main-nav">
                   {menu}
               </nav>
           </div>
       </div>
   </div>
</header>',
       'footer' => '<footer class="site-footer">
   <div class="container">
       <div class="row">
           <div class="col-md-6">
               <p>&copy; {current_year} {site_name}. All rights reserved.</p>
           </div>
           <div class="col-md-6 text-end">
               <nav class="footer-nav">
                   {menu}
               </nav>
           </div>
       </div>
   </div>
</footer>',
       'sidebar' => '<aside class="sidebar">
   <div class="widget">
       <h3>About {site_name}</h3>
       <p>Welcome to our website. Here you can find various information about our products and services.</p>
   </div>
   <div class="widget">
       <h3>Navigation</h3>
       <nav class="sidebar-nav">
           {menu}
       </nav>
   </div>
</aside>'
   ];

   $pageTitle = 'Create New Component - ' . htmlspecialchars($site['domain']);

} catch (Exception $e) {
   error_log("Component create error: " . $e->getMessage());
   $error = "System error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
   <meta charset="UTF-8">
   <meta name="viewport" content="width=device-width, initial-scale=1.0">
   <title><?php echo $pageTitle; ?> - PBN Admin</title>
   <!-- Bootstrap CSS (from CDN) -->
   <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
   <!-- Font Awesome (from CDN) -->
   <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
   <!-- CodeMirror for code editing -->
   <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.css">
   <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/theme/monokai.min.css">
   <!-- Custom CSS -->
   <style>
       body {
           font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
           line-height: 1.6;
           background: #f5f5f5;
           margin: 0;
           padding: 0;
       }
       .navbar {
           background-color: #2c3e50 !important;
           padding: 0.5rem 1rem;
       }
       .navbar-brand {
           color: white !important;
           font-weight: bold;
           font-size: 1.5rem;
       }
       .nav-link {
           color: rgba(255,255,255,0.8) !important;
       }
       .nav-link:hover, .nav-link.active {
           color: white !important;
       }
       .card {
           box-shadow: 0 2px 5px rgba(0,0,0,0.1);
           border: none;
           margin-bottom: 20px;
       }
       footer {
           margin-top: 3rem;
           padding: 1.5rem 0;
           background: #f8f9fa;
           border-top: 1px solid #e9ecef;
       }
       .CodeMirror {
           height: 500px;
           border: 1px solid #ddd;
           border-radius: 4px;
       }
       .component-type-radio {
           display: flex;
           gap: 15px;
           margin-bottom: 20px;
       }
       .component-type-option {
           flex: 1;
           border: 1px solid #ddd;
           border-radius: 5px;
           padding: 15px;
           text-align: center;
           cursor: pointer;
           transition: all 0.2s ease;
       }
       .component-type-option:hover {
           background-color: #f8f9fa;
           transform: translateY(-2px);
       }
       .component-type-option.active {
           border-color: #3498db;
           background-color: #ebf7ff;
       }
       .component-icon {
           font-size: 2rem;
           margin-bottom: 10px;
       }
       .header-icon { color: #3498db; }
       .footer-icon { color: #2ecc71; }
       .sidebar-icon { color: #9b59b6; }
   </style>
</head>
<body>
   <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
       <div class="container-fluid">
           <a class="navbar-brand" href="index.php">PBN Admin</a>
           <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
               <span class="navbar-toggler-icon"></span>
           </button>
           <div class="collapse navbar-collapse" id="navbarNav">
               <ul class="navbar-nav">
                   <li class="nav-item">
                       <a class="nav-link" href="index.php">
                           <i class="fas fa-tachometer-alt"></i> Dashboard
                       </a>
                   </li>
                   <li class="nav-item">
                       <a class="nav-link" href="sites.php">
                           <i class="fas fa-globe"></i> Sites
                       </a>
                   </li>
                   <li class="nav-item">
                       <a class="nav-link" href="pages.php">
                           <i class="fas fa-file-alt"></i> Pages
                       </a>
                   </li>
                   <li class="nav-item">
                       <a class="nav-link active" href="components.php">
                           <i class="fas fa-puzzle-piece"></i> Components
                       </a>
                   </li>
               </ul>
               <ul class="navbar-nav ms-auto">
                   <li class="nav-item dropdown">
                       <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                           <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                       </a>
                       <ul class="dropdown-menu dropdown-menu-end">
                           <li>
                               <a class="dropdown-item" href="#">
                                   <i class="fas fa-user-cog"></i> Profile
                               </a>
                           </li>
                           <li><hr class="dropdown-divider"></li>
                           <li>
                               <a class="dropdown-item" href="logout.php">
                                   <i class="fas fa-sign-out-alt"></i> Logout
                               </a>
                           </li>
                       </ul>
                   </li>
               </ul>
           </div>
       </div>
   </nav>
   
   <div class="container-fluid mt-4">
       <div class="d-flex justify-content-between align-items-center mb-4">
           <div>
               <h1>Create New Component</h1>
               <nav aria-label="breadcrumb">
                   <ol class="breadcrumb">
                       <li class="breadcrumb-item"><a href="sites.php">Sites</a></li>
                       <li class="breadcrumb-item">
                           <a href="components.php?site_id=<?php echo $siteId; ?>">
                               <?php echo htmlspecialchars($site['domain']); ?>
                           </a>
                       </li>
                       <li class="breadcrumb-item active">New Component</li>
                   </ol>
               </nav>
           </div>
           
           <a href="components.php?site_id=<?php echo $siteId; ?>" class="btn btn-secondary">
               <i class="fas fa-arrow-left"></i> Back to Components
           </a>
       </div>
       
       <?php if (isset($error)): ?>
           <div class="alert alert-danger">
               <?php echo $error; ?>
           </div>
       <?php endif; ?>
       
       <?php if (!empty($errors)): ?>
           <div class="alert alert-danger">
               <h5><i class="fas fa-exclamation-circle"></i> Validation Errors</h5>
               <ul class="mb-0">
                   <?php foreach ($errors as $errMsg): ?>
                       <li><?php echo htmlspecialchars($errMsg); ?></li>
                   <?php endforeach; ?>
               </ul>
           </div>
       <?php endif; ?>
       
       <div class="card">
           <div class="card-body">
               <form method="post" action="component-create.php?site_id=<?php echo $siteId; ?>">
                   <div class="mb-3">
                       <label for="name" class="form-label">Component Name *</label>
                       <input type="text" class="form-control" id="name" name="name" 
                              value="<?php echo htmlspecialchars($_POST['name'] ?? ''); ?>" required>
                       <div class="form-text">
                           Give your component a descriptive name (e.g. "Main Header", "Copyright Footer")
                       </div>
                   </div>
                   
                   <div class="mb-4">
                       <label class="form-label">Component Type *</label>
                       <div class="component-type-radio">
                           <div class="component-type-option" data-type="header">
                               <div class="component-icon header-icon">
                                   <i class="fas fa-heading"></i>
                               </div>
                               <h5>Header</h5>
                               <p class="mb-0 text-muted">Page top section</p>
                               <input type="radio" name="type" value="header" id="type-header" class="d-none" 
                                      <?php echo (isset($_POST['type']) && $_POST['type'] === 'header') ? 'checked' : ''; ?>>
                           </div>
                           
                           <div class="component-type-option" data-type="footer">
                               <div class="component-icon footer-icon">
                                   <i class="fas fa-shoe-prints"></i>
                               </div>
                               <h5>Footer</h5>
                               <p class="mb-0 text-muted">Page bottom section</p>
                               <input type="radio" name="type" value="footer" id="type-footer" class="d-none" 
                                      <?php echo (isset($_POST['type']) && $_POST['type'] === 'footer') ? 'checked' : ''; ?>>
                           </div>
                           
                           <div class="component-type-option" data-type="sidebar">
                               <div class="component-icon sidebar-icon">
                                   <i class="fas fa-columns"></i>
                               </div>
                               <h5>Sidebar</h5>
                               <p class="mb-0 text-muted">Side content area</p>
                               <input type="radio" name="type" value="sidebar" id="type-sidebar" class="d-none" 
                                      <?php echo (isset($_POST['type']) && $_POST['type'] === 'sidebar') ? 'checked' : ''; ?>>
                           </div>
                       </div>
                   </div>
                   
                   <div class="mb-3">
                       <label for="content" class="form-label">HTML Content *</label>
                       <textarea id="content" name="content" class="form-control"><?php echo htmlspecialchars($_POST['content'] ?? ''); ?></textarea>
                       <div class="form-text">
                           Use HTML to design your component. Available variables:
                           <code>{site_title}</code>, <code>{site_name}</code>, <code>{site_url}</code>, 
                           <code>{menu}</code>, <code>{current_year}</code>
                       </div>
                   </div>
                   
                   <div class="mb-4">
                       <div class="form-check">
                           <input type="checkbox" class="form-check-input" id="is_active" name="is_active" 
                                 <?php echo (!isset($_POST['is_active']) || $_POST['is_active']) ? 'checked' : ''; ?>>
                           <label class="form-check-label" for="is_active">Active</label>
                           <div class="form-text">
                               Only active components will be displayed on the site.
                               You can have multiple components of the same type, but only active ones will be used.
                           </div>
                       </div>
                   </div>
                   
                   <div class="d-flex justify-content-between">
                       <a href="components.php?site_id=<?php echo $siteId; ?>" class="btn btn-secondary">Cancel</a>
                       <button type="submit" class="btn btn-primary">Create Component</button>
                   </div>
               </form>
           </div>
       </div>
   </div>
   
   <footer class="text-center text-muted">
       <div class="container">
           <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
       </div>
   </footer>
   
   <!-- Bootstrap Bundle with Popper (from CDN) -->
   <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
   <!-- CodeMirror JS -->
   <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.js"></script>
   <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/htmlmixed/htmlmixed.min.js"></script>
   <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/xml/xml.min.js"></script>
   <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/javascript/javascript.min.js"></script>
   <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/css/css.min.js"></script>
   <script>
   document.addEventListener('DOMContentLoaded', function() {
       // Initialize CodeMirror for HTML editing
       var editor = CodeMirror.fromTextArea(document.getElementById('content'), {
           mode: 'htmlmixed',
           theme: 'monokai',
           lineNumbers: true,
           lineWrapping: true,
           autoCloseTags: true,
           autoCloseBrackets: true,
           matchBrackets: true,
           indentUnit: 4
       });
       
       // Component type selection
       const typeOptions = document.querySelectorAll('.component-type-option');
       typeOptions.forEach(option => {
           // Set initial active state if a type was previously selected
           const radioInput = option.querySelector('input[type="radio"]');
           if (radioInput.checked) {
               option.classList.add('active');
           }
           
           option.addEventListener('click', function() {
               // Remove active class from all options
               typeOptions.forEach(opt => opt.classList.remove('active'));
               
               // Add active class to clicked option
               this.classList.add('active');
               
               // Check the radio button
               const type = this.getAttribute('data-type');
               document.getElementById('type-' + type).checked = true;
               
               // Set template content
               if (editor.getValue().trim() === '') {
                   editor.setValue(<?php echo json_encode($templateHTML); ?>[type] || '');
               }
           });
       });
       
       // Check if a type was already selected (in case of form validation error)
       const selectedType = document.querySelector('input[name="type"]:checked');
       if (selectedType) {
           document.querySelector(`.component-type-option[data-type="${selectedType.value}"]`).classList.add('active');
       }
   });
   </script>
</body>
</html>