<?php
// admin/component-edit.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем AuthManager
    $authManager = new AuthManager($db);

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя
    $currentUser = $authManager->getCurrentUser();

    // Получаем ID компонента
    $componentId = isset($_GET['id']) ? (int)$_GET['id'] : null;
    
    if (!$componentId) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Component ID is required'
        ];
        header('Location: components.php');
        exit;
    }

    // Получаем информацию о компоненте
    $stmt = $db->prepare("
        SELECT c.*, s.domain 
        FROM components c
        JOIN sites s ON c.site_id = s.id
        WHERE c.id = :id
    ");
    $stmt->bindValue(':id', $componentId, PDO::PARAM_INT);
    $stmt->execute();
    $component = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$component) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Component not found'
        ];
        header('Location: components.php');
        exit;
    }

    // Обработка формы редактирования
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $name = trim($_POST['name'] ?? '');
        $content = $_POST['content'] ?? '';
        $isActive = isset($_POST['is_active']) ? 1 : 0;
        
        // Валидация
        $errors = [];
        if (empty($name)) {
            $errors[] = "Name is required";
        }
        
        if (empty($content)) {
            $errors[] = "Content is required";
        }
        
        if (empty($errors)) {
            // Обновляем компонент
            $updateStmt = $db->prepare("
                UPDATE components 
                SET 
                    name = :name,
                    content = :content,
                    is_active = :is_active,
                    updated_at = CURRENT_TIMESTAMP
                WHERE id = :id
            ");
            
            $updateStmt->bindValue(':name', $name, PDO::PARAM_STR);
            $updateStmt->bindValue(':content', $content, PDO::PARAM_STR);
            $updateStmt->bindValue(':is_active', $isActive, PDO::PARAM_INT);
            $updateStmt->bindValue(':id', $componentId, PDO::PARAM_INT);
            $updateStmt->execute();
            
            // Логируем обновление
            $logger = new SystemLogger($db);
            $logger->log(
                $component['site_id'],
                'component_updated',
                "Component '{$name}' (ID: {$componentId}) updated by {$currentUser['username']}",
                'success'
            );
            
            $_SESSION['notification'] = [
                'type' => 'success',
                'message' => "Component '{$name}' has been successfully updated"
            ];
            
            // Перенаправляем на страницу компонентов
            header('Location: components.php?site_id=' . $component['site_id']);
            exit;
        }
    }

    $pageTitle = 'Edit Component - ' . htmlspecialchars($component['name']);

} catch (Exception $e) {
    error_log("Component edit error: " . $e->getMessage());
    $error = "System error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - PBN Admin</title>
    <!-- Bootstrap CSS (from CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome (from CDN) -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- CodeMirror for code editing -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/theme/monokai.min.css">
    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            background: #f5f5f5;
            margin: 0;
            padding: 0;
        }
        .navbar {
            background-color: #2c3e50 !important;
            padding: 0.5rem 1rem;
        }
        .navbar-brand {
            color: white !important;
            font-weight: bold;
            font-size: 1.5rem;
        }
        .nav-link {
            color: rgba(255,255,255,0.8) !important;
        }
        .nav-link:hover, .nav-link.active {
            color: white !important;
        }
        .card {
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            border: none;
            margin-bottom: 20px;
        }
        footer {
            margin-top: 3rem;
            padding: 1.5rem 0;
            background: #f8f9fa;
            border-top: 1px solid #e9ecef;
        }
        .CodeMirror {
            height: 500px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        .badge-header {
            background-color: #3498db;
        }
        .badge-footer {
            background-color: #2ecc71;
        }
        .badge-sidebar {
            background-color: #9b59b6;
        }
        .component-type {
            font-size: 1.1rem;
            margin-left: 10px;
        }
        .header-component { color: #3498db; }
        .footer-component { color: #2ecc71; }
        .sidebar-component { color: #9b59b6; }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand" href="index.php">PBN Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="index.php">
                            <i class="fas fa-tachometer-alt"></i> Dashboard
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sites.php">
                            <i class="fas fa-globe"></i> Sites
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="pages.php">
                            <i class="fas fa-file-alt"></i> Pages
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="components.php">
                            <i class="fas fa-puzzle-piece"></i> Components
                        </a>
                    </li>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                            <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user-cog"></i> Profile
                                </a>
                            </li>
                            <li><hr class="dropdown-divider"></li>
                            <li>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt"></i> Logout
                                </a>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
    
    <div class="container-fluid mt-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                <h1>
                    Edit Component
                    <span class="component-type <?php echo $component['type']; ?>-component">
                        (<?php echo ucfirst(htmlspecialchars($component['type'])); ?>)
                    </span>
                </h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="sites.php">Sites</a></li>
                        <li class="breadcrumb-item">
                            <a href="components.php?site_id=<?php echo $component['site_id']; ?>">
                                <?php echo htmlspecialchars($component['domain']); ?>
                            </a>
                        </li>
                        <li class="breadcrumb-item active"><?php echo htmlspecialchars($component['name']); ?></li>
                    </ol>
                </nav>
            </div>
            
            <a href="components.php?site_id=<?php echo $component['site_id']; ?>" class="btn btn-secondary">
                <i class="fas fa-arrow-left"></i> Back to Components
            </a>
        </div>
        
        <?php if (isset($error)): ?>
            <div class="alert alert-danger">
                <?php echo $error; ?>
            </div>
        <?php endif; ?>
        
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <h5><i class="fas fa-exclamation-circle"></i> Validation Errors</h5>
                <ul class="mb-0">
                    <?php foreach ($errors as $errMsg): ?>
                        <li><?php echo htmlspecialchars($errMsg); ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <div class="card">
            <div class="card-body">
                <form method="post" action="component-edit.php?id=<?php echo $componentId; ?>">
                    <div class="mb-3">
                        <label for="name" class="form-label">Component Name *</label>
                        <input type="text" class="form-control" id="name" name="name" 
                               value="<?php echo htmlspecialchars($component['name']); ?>" required>
                    </div>
                    
                    <div class="mb-3">
                        <label for="content" class="form-label">HTML Content *</label>
                        <textarea id="content" name="content" class="form-control"><?php echo htmlspecialchars($component['content']); ?></textarea>
                        <div class="form-text">
                            Use HTML to design your component. Available variables:
                            <code>{site_title}</code>, <code>{site_name}</code>, <code>{site_url}</code>, 
                            <code>{menu}</code>, <code>{current_year}</code>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="is_active" name="is_active" 
                                  <?php echo $component['is_active'] ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="is_active">Active</label>
                            <div class="form-text">
                                Only active components will be displayed on the site.
                                You can have multiple components of the same type, but only active ones will be used.
                            </div>
                        </div>
                    </div>
                    
                    <div class="d-flex justify-content-between">
                        <a href="components.php?site_id=<?php echo $component['site_id']; ?>" class="btn btn-secondary">Cancel</a>
                        <button type="submit" class="btn btn-primary">Save Changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <footer class="text-center text-muted">
        <div class="container">
            <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Bootstrap Bundle with Popper (from CDN) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <!-- CodeMirror JS -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/codemirror.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/htmlmixed/htmlmixed.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/xml/xml.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/javascript/javascript.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.2/mode/css/css.min.js"></script>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // Initialize CodeMirror for HTML editing
        var editor = CodeMirror.fromTextArea(document.getElementById('content'), {
            mode: 'htmlmixed',
            theme: 'monokai',
            lineNumbers: true,
            lineWrapping: true,
            autoCloseTags: true,
            autoCloseBrackets: true,
            matchBrackets: true,
            indentUnit: 4
        });
    });
    </script>
</body>
</html>