<?php
// admin/deploy_site.php
require_once '../config/init.php';
checkAuth();

$db = getDB();
$deployManager = new DeploymentManager($db);
$logger = new SystemLogger($db);

$site_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

// Get site information
$stmt = $db->prepare("SELECT * FROM sites WHERE id = ?");
$stmt->execute([$site_id]);
$site = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$site) {
    $logger->log(null, 'deploy_error', "Site not found: ID $site_id", 'error');
    header('Location: sites.php?error=site_not_found');
    exit;
}

// Process deployment
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $deployOptions = [
            'update_files' => isset($_POST['update_files']),
            'update_apache' => isset($_POST['update_apache']),
            'update_cloudflare' => isset($_POST['update_cloudflare']),
            'force_ssl' => isset($_POST['force_ssl']),
            'rebuild_htaccess' => isset($_POST['rebuild_htaccess']),
        ];
        
        $result = $deployManager->deploySite($site_id, $deployOptions);
        $success = true;
        $messages = $result['messages'];
        
    } catch (Exception $e) {
        $logger->log($site_id, 'deploy_error', $e->getMessage(), 'error');
        $error = $e->getMessage();
    }
}

// Get deployment history
$deployHistory = $deployManager->getDeploymentHistory($site_id, 5);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Deploy Site - <?= htmlspecialchars($site['domain']) ?></title>
    <link rel="stylesheet" href="assets/css/admin.css">
</head>
<body>
    <?php include 'includes/header.php'; ?>
    
    <div class="admin-container">
        <?php include 'includes/sidebar.php'; ?>
        
        <main class="main-content">
            <div class="content-header">
                <h1>Deploy Site: <?= htmlspecialchars($site['domain']) ?></h1>
                <div class="actions">
                    <a href="edit_site.php?id=<?= $site_id ?>" class="btn secondary">Edit Site</a>
                    <a href="sites.php" class="btn">Back to Sites</a>
                </div>
            </div>
            
            <?php if (isset($error)): ?>
                <div class="alert error">
                    <h4>Deployment Error</h4>
                    <p><?= htmlspecialchars($error) ?></p>
                </div>
            <?php endif; ?>
            
            <?php if (isset($success)): ?>
                <div class="alert success">
                    <h4>Deployment Successful</h4>
                    <p>The site has been deployed successfully.</p>
                </div>
                
                <?php if (!empty($messages)): ?>
                    <div class="deployment-log">
                        <h3>Deployment Log</h3>
                        <div class="log-container">
                            <?php foreach ($messages as $message): ?>
                                <div class="log-entry <?= $message['type'] ?>">
                                    <span class="log-time"><?= $message['time'] ?></span>
                                    <span class="log-message"><?= htmlspecialchars($message['message']) ?></span>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
            
            <div class="deploy-container">
                <div class="site-info card">
                    <h2>Site Information</h2>
                    <table class="info-table">
                        <tr>
                            <th>Domain:</th>
                            <td><?= htmlspecialchars($site['domain']) ?></td>
                        </tr>
                        <tr>
                            <th>Status:</th>
                            <td>
                                <span class="badge <?= $site['active'] ? 'success' : 'error' ?>">
                                    <?= $site['active'] ? 'Active' : 'Inactive' ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <th>SSL:</th>
                            <td>
                                <span class="badge <?= $site['ssl_enabled'] ? 'success' : 'warning' ?>">
                                    <?= $site['ssl_enabled'] ? 'Enabled' : 'Disabled' ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <th>CloudFlare:</th>
                            <td>
                                <span class="badge <?= $site['cloudflare_enabled'] ? 'success' : 'warning' ?>">
                                    <?= $site['cloudflare_enabled'] ? 'Enabled' : 'Disabled' ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <th>Created:</th>
                            <td><?= date('F j, Y', strtotime($site['created_at'])) ?></td>
                        </tr>
                        <tr>
                            <th>Last Updated:</th>
                            <td><?= date('F j, Y g:i a', strtotime($site['updated_at'])) ?></td>
                        </tr>
                    </table>
                </div>
                
                <div class="deployment-options card">
                    <h2>Deployment Options</h2>
                    
                    <form method="post" id="deployForm">
                        <div class="form-group checkbox">
                            <input type="checkbox" id="update_files" name="update_files" checked>
                            <label for="update_files">Update Site Files</label>
                            <small>Updates index.php and config files</small>
                        </div>
                        
                        <div class="form-group checkbox">
                            <input type="checkbox" id="update_apache" name="update_apache" checked>
                            <label for="update_apache">Update Apache Configuration</label>
                            <small>Regenerates and applies Apache configuration</small>
                        </div>
                        
                        <div class="form-group checkbox">
                            <input type="checkbox" id="update_cloudflare" name="update_cloudflare" checked>
                            <label for="update_cloudflare">Update CloudFlare Settings</label>
                            <small>Updates DNS, SSL, and cache settings</small>
                        </div>
                        
                        <div class="form-group checkbox">
                            <input type="checkbox" id="force_ssl" name="force_ssl" 
                                   <?= $site['ssl_enabled'] ? 'checked' : '' ?>>
                            <label for="force_ssl">Force SSL</label>
                            <small>Redirect HTTP to HTTPS</small>
                        </div>
                        
                        <div class="form-group checkbox">
                            <input type="checkbox" id="rebuild_htaccess" name="rebuild_htaccess" checked>
                            <label for="rebuild_htaccess">Rebuild .htaccess</label>
                            <small>Regenerates .htaccess with current settings</small>
                        </div>
                        
                        <div class="form-actions">
                            <button type="submit" class="btn primary">Deploy Site</button>
                        </div>
                    </form>
                </div>
            </div>
            
            <div class="deployment-history card">
                <h2>Deployment History</h2>
                
                <?php if (empty($deployHistory)): ?>
                    <p class="empty-state">No deployment history available</p>
                <?php else: ?>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>Date</th>
                                <th>User</th>
                                <th>Type</th>
                                <th>Status</th>
                                <th>Duration</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($deployHistory as $deployment): ?>
                            <tr>
                                <td><?= date('M j, Y g:i a', strtotime($deployment['created_at'])) ?></td>
                                <td><?= htmlspecialchars($deployment['username']) ?></td>
                                <td><?= htmlspecialchars($deployment['type']) ?></td>
                                <td>
                                    <span class="badge <?= $deployment['status'] ?>">
                                        <?= ucfirst($deployment['status']) ?>
                                    </span>
                                </td>
                                <td><?= $deployment['duration'] ?> seconds</td>
                                <td>
                                    <a href="deployment_details.php?id=<?= $deployment['id'] ?>" 
                                       class="btn-icon" title="View Details">
                                        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
                                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M2.458 12C3.732 7.943 7.523 5 12 5c4.478 0 8.268 2.943 9.542 7-1.274 4.057-5.064 7-9.542 7-4.477 0-8.268-2.943-9.542-7z" />
                                        </svg>
                                    </a>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                    <a href="deployments.php?site_id=<?= $site_id ?>" class="view-all">View All Deployments</a>
                <?php endif; ?>
            </div>
        </main>
    </div>
    
    <script src="assets/js/admin.js"></script>
</body>
</html>