<?php
// admin/page-edit.php

// Подключаем конфигурацию перед запуском сессии
require_once __DIR__ . '/../config/config.php';

// Запускаем сессию
session_start();

// Включаем отображение ошибок для отладки
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

$pageTitle = isset($_GET['id']) ? 'Edit Page' : 'Create New Page';

// Подключаем необходимые файлы
require_once __DIR__ . '/../includes/AuthManager.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/ContentManager.php';

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем логгер и другие сервисы
    $logger = new SystemLogger($db);
    $authManager = new AuthManager($db);
    $contentManager = new ContentManager($db);

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя
    $currentUser = $authManager->getCurrentUser();

    // Get site ID and page ID
    $siteId = isset($_GET['site_id']) ? (int)$_GET['site_id'] : null;
    $pageId = isset($_GET['id']) ? (int)$_GET['id'] : null;

    // Validate site ID
    if (!$siteId) {
        $_SESSION['notifications'][] = [
            'type' => 'danger',
            'message' => 'Site ID is required'
        ];
        header('Location: sites.php');
        exit;
    }

    // Get site info
    $stmt = $db->prepare("SELECT domain, title FROM sites WHERE id = ?");
    $stmt->execute([$siteId]);
    $site = $stmt->fetch(PDO::FETCH_ASSOC);
    if (!$site) {
        $_SESSION['notifications'][] = [
            'type' => 'danger',
            'message' => 'Site not found'
        ];
        header('Location: sites.php');
        exit;
    }

    // Update page title
    $pageTitle = isset($_GET['id']) 
        ? "Edit Page - {$site['domain']}" 
        : "Create New Page - {$site['domain']}";

    // Get page data if editing
    $page = null;
    if ($pageId) {
        $page = $contentManager->getPage($pageId);
        
        if (!$page || $page['site_id'] != $siteId) {
            $_SESSION['notifications'][] = [
                'type' => 'danger',
                'message' => 'Page not found'
            ];
            header("Location: pages.php?site_id={$siteId}");
            exit;
        }
    }

    // Process form submission
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        try {
            $pageData = [
                'title' => $_POST['title'] ?? '',
                'slug' => $_POST['slug'] ?? '',
                'content' => $_POST['content'] ?? '',
                'h1' => $_POST['h1'] ?? '',
                'meta_title' => $_POST['meta_title'] ?? '',
                'meta_description' => $_POST['meta_description'] ?? '',
                'is_published' => isset($_POST['is_published']) ? 1 : 0,
                'is_system' => isset($_POST['is_system']) ? 1 : 0
            ];
            
            if (empty($pageData['title'])) {
                throw new Exception('Title is required');
            }
            
            if ($pageId) {
                // Update existing page
                $contentManager->updatePage($pageId, $pageData);
                $_SESSION['notifications'][] = [
                    'type' => 'success',
                    'message' => 'Page updated successfully'
                ];
            } else {
                // Create new page
                $contentManager->createPage($siteId, $pageData);
                $_SESSION['notifications'][] = [
                    'type' => 'success',
                    'message' => 'Page created successfully'
                ];
            }
            
            header("Location: pages.php?site_id={$siteId}");
            exit;
            
        } catch (Exception $e) {
            $error = $e->getMessage();
        }
    }

} catch (Exception $e) {
    $error = "System error: " . $e->getMessage();
    $logger->log(0, 'page_edit', "Error: " . $e->getMessage(), 'error');
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($pageTitle); ?> - PBN Admin</title>
    
    <!-- Bootstrap CSS (from CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    
    <!-- Font Awesome (from CDN) -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    
    <!-- Summernote Editor -->
    <link href="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-bs4.min.css" rel="stylesheet">
    
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/admin.css">
    
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            background: #f5f5f5;
        }
        .navbar {
            background-color: #2c3e50 !important;
            padding: 0.5rem 1rem;
        }
        .navbar-brand {
            color: white !important;
            font-weight: bold;
            font-size: 1.5rem;
        }
        .nav-link {
            color: rgba(255,255,255,0.8) !important;
        }
        .nav-link:hover, .nav-link.active {
            color: white !important;
        }
        .card {
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            border: none;
            margin-bottom: 20px;
        }
        footer {
            margin-top: 3rem;
            padding: 1.5rem 0;
            background: #f8f9fa;
            border-top: 1px solid #e9ecef;
        }
        .form-control:focus {
            box-shadow: 0 0 0 0.25rem rgba(44, 62, 80, 0.25);
            border-color: #2c3e50;
        }
        .btn-primary {
            background-color: #2c3e50;
            border-color: #2c3e50;
        }
        .btn-primary:hover {
            background-color: #1a252f;
            border-color: #1a252f;
        }
        .note-editor {
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand" href="index.php">PBN Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="index.php">
                            <i class="fas fa-tachometer-alt"></i> Dashboard
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sites.php">
                            <i class="fas fa-globe"></i> Sites
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="pages.php">
                            <i class="fas fa-file-alt"></i> Pages
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="components.php">
                            <i class="fas fa-puzzle-piece"></i> Components
                        </a>
                    </li>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                            <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user-cog"></i> Profile
                                </a>
                            </li>
                            <li><hr class="dropdown-divider"></li>
                            <li>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt"></i> Logout
                                </a>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container-fluid mt-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1><?php echo htmlspecialchars($pageId ? 'Edit Page' : 'Create New Page'); ?></h1>
            <a href="pages.php?site_id=<?php echo $siteId; ?>" class="btn btn-secondary">
                <i class="fas fa-arrow-left"></i> Back to Pages
            </a>
        </div>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger">
                <h5><i class="fas fa-exclamation-triangle"></i> Error</h5>
                <p class="mb-0"><?php echo htmlspecialchars($error); ?></p>
            </div>
        <?php endif; ?>

        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0">
                    <i class="fas fa-file-alt"></i> 
                    <?php echo htmlspecialchars($pageId ? 'Edit Page Details' : 'Page Details'); ?>
                    <span class="badge bg-info ms-2"><?php echo htmlspecialchars($site['domain']); ?></span>
                </h5>
            </div>
            <div class="card-body">
                <form method="post" action="page-edit.php?site_id=<?php echo $siteId; ?><?php echo $pageId ? '&id=' . $pageId : ''; ?>">
                    <div class="row mb-4">
                        <div class="col-md-6">
                            <label for="title" class="form-label">Title *</label>
                            <input type="text" class="form-control" id="title" name="title" 
                                   value="<?php echo htmlspecialchars($page['title'] ?? $_POST['title'] ?? ''); ?>" required>
                        </div>
                        
                        <div class="col-md-6">
                            <label for="slug" class="form-label">Slug</label>
                            <input type="text" class="form-control" id="slug" name="slug" 
                                   value="<?php echo htmlspecialchars($page['slug'] ?? $_POST['slug'] ?? ''); ?>">
                            <div class="form-text">Leave empty to auto-generate from title. Use only lowercase letters, numbers, and hyphens.</div>
                        </div>
                    </div>
                    
                    <div class="row mb-4">
                        <div class="col-md-6">
                            <label for="h1" class="form-label">H1</label>
                            <input type="text" class="form-control" id="h1" name="h1" 
                                   value="<?php echo htmlspecialchars($page['h1'] ?? $_POST['h1'] ?? ''); ?>">
                            <div class="form-text">Main heading of the page. Defaults to title if left empty.</div>
                        </div>
                        
                        <div class="col-md-6">
                            <label for="meta_title" class="form-label">Meta Title</label>
                            <input type="text" class="form-control" id="meta_title" name="meta_title" 
                                   value="<?php echo htmlspecialchars($page['meta_title'] ?? $_POST['meta_title'] ?? ''); ?>">
                            <div class="form-text">Used for SEO. Defaults to title if left empty.</div>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="meta_description" class="form-label">Meta Description</label>
                        <textarea class="form-control" id="meta_description" name="meta_description" rows="2"><?php echo htmlspecialchars($page['meta_description'] ?? $_POST['meta_description'] ?? ''); ?></textarea>
                        <div class="form-text">Short description for search engines.</div>
                    </div>
                    
                    <div class="mb-4">
                        <label for="content" class="form-label">Content *</label>
                        <textarea class="form-control" id="content" name="content" rows="15"><?php echo htmlspecialchars($page['content'] ?? $_POST['content'] ?? ''); ?></textarea>
                    </div>
                    
                    <div class="row mb-4">
                        <div class="col-md-6">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="is_published" name="is_published" 
                                       <?php echo (isset($page) && isset($page['is_published']) && $page['is_published']) || 
                                             isset($_POST['is_published']) || 
                                             !isset($page) ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="is_published">Published</label>
                            </div>
                        </div>
                        
                        <div class="col-md-6">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="is_system" name="is_system" 
                                       <?php echo (isset($page) && $page['is_system']) || isset($_POST['is_system']) ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="is_system">System Page</label>
                                <small class="form-text d-block">System pages (like 404) are protected from deletion.</small>
                            </div>
                        </div>
                    </div>
                    
                    <?php if ($pageId): ?>
                    <div class="alert alert-info">
                        <div class="row">
                            <div class="col-md-6">
                                <p class="mb-1"><strong>Created:</strong> <?php echo htmlspecialchars($page['created_at']); ?></p>
                            </div>
                            <div class="col-md-6">
                                <p class="mb-1"><strong>Last Updated:</strong> <?php echo htmlspecialchars($page['updated_at']); ?></p>
                            </div>
                        </div>
                    </div>
                    <?php endif; ?>
                    
                    <div class="d-flex justify-content-between mt-4">
                        <a href="pages.php?site_id=<?php echo $siteId; ?>" class="btn btn-secondary">Cancel</a>
                        <button type="submit" class="btn btn-primary"><?php echo $pageId ? 'Update Page' : 'Create Page'; ?></button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <footer class="text-center text-muted">
        <div class="container">
            <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- jQuery and Bootstrap Bundle with Popper -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    
    <!-- Summernote Editor -->
    <script src="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-bs4.min.js"></script>
    
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // Инициализация редактора Summernote
        $('#content').summernote({
            height: 300,
            toolbar: [
                ['style', ['style']],
                ['font', ['bold', 'underline', 'clear']],
                ['color', ['color']],
                ['para', ['ul', 'ol', 'paragraph']],
                ['table', ['table']],
                ['insert', ['link', 'picture']],
                ['view', ['fullscreen', 'codeview', 'help']]
            ]
        });
        
        // Автоматическое создание slug из заголовка
        const titleInput = document.getElementById('title');
        const slugInput = document.getElementById('slug');
        
        if (titleInput && slugInput) {
            titleInput.addEventListener('blur', function() {
                if (titleInput.value && !slugInput.value) {
                    // Конвертируем заголовок в slug
                    let slug = titleInput.value.toLowerCase()
                        .replace(/[^\w\s-]/g, '') // Удаляем спецсимволы
                        .replace(/\s+/g, '-')     // Заменяем пробелы на дефисы
                        .replace(/--+/g, '-');    // Заменяем множественные дефисы на один
                    
                    slugInput.value = slug;
                }
            });
        }
        
        // Копирование заголовка в H1 и Meta Title
        const h1Input = document.getElementById('h1');
        const metaTitleInput = document.getElementById('meta_title');
        
        if (titleInput && h1Input && metaTitleInput) {
            titleInput.addEventListener('blur', function() {
                if (titleInput.value && !h1Input.value) {
                    h1Input.value = titleInput.value;
                }
                
                if (titleInput.value && !metaTitleInput.value) {
                    metaTitleInput.value = titleInput.value;
                }
            });
        }
    });
    </script>
</body>
</html>