<?php
// admin/pages.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

try {
   // Инициализируем подключение к базе данных
   $db = new PDO(
       "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
       DB_USER,
       DB_PASS,
       array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
   );

   // Инициализируем AuthManager
   $authManager = new AuthManager($db);

   // Проверяем авторизацию
   if (!$authManager->isAuthenticated()) {
       header('Location: login.php');
       exit;
   }

   // Получаем текущего пользователя
   $currentUser = $authManager->getCurrentUser();

   // Получаем site_id из GET-параметра
   $siteId = isset($_GET['site_id']) ? (int)$_GET['site_id'] : null;
   $site = null;

   // Если site_id указан, получаем информацию о сайте
   if ($siteId) {
       $siteStmt = $db->prepare("SELECT id, domain, title FROM sites WHERE id = ?");
       $siteStmt->execute([$siteId]);
       $site = $siteStmt->fetch(PDO::FETCH_ASSOC);

       if (!$site) {
           $_SESSION['notification'] = [
               'type' => 'danger',
               'message' => 'Site not found.'
           ];
           header('Location: sites.php');
           exit;
       }
   }

   // Настраиваем пагинацию
   $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
   $perPage = 15;
   $offset = ($page - 1) * $perPage;

   // Получаем список страниц (для конкретного сайта или для всех сайтов)
   $pages = [];
   $totalPages = 0;

   if ($siteId) {
       // Получаем страницы для конкретного сайта
       $countStmt = $db->prepare("SELECT COUNT(*) FROM pages WHERE site_id = ?");
       $countStmt->execute([$siteId]);
       $totalRecords = $countStmt->fetchColumn();
       $totalPages = ceil($totalRecords / $perPage);

       $pagesStmt = $db->prepare("
           SELECT p.*, s.domain 
           FROM pages p 
           JOIN sites s ON p.site_id = s.id
           WHERE p.site_id = ? 
           ORDER BY p.created_at DESC 
           LIMIT ?, ?
       ");
       $pagesStmt->bindParam(1, $siteId, PDO::PARAM_INT);
       $pagesStmt->bindParam(2, $offset, PDO::PARAM_INT);
       $pagesStmt->bindParam(3, $perPage, PDO::PARAM_INT);
       $pagesStmt->execute();
       $pages = $pagesStmt->fetchAll(PDO::FETCH_ASSOC);
   } else {
       // Получаем страницы для всех сайтов
       $countStmt = $db->query("SELECT COUNT(*) FROM pages");
       $totalRecords = $countStmt->fetchColumn();
       $totalPages = ceil($totalRecords / $perPage);

       $pagesStmt = $db->prepare("
           SELECT p.*, s.domain 
           FROM pages p 
           JOIN sites s ON p.site_id = s.id 
           ORDER BY p.created_at DESC 
           LIMIT ?, ?
       ");
       $pagesStmt->bindParam(1, $offset, PDO::PARAM_INT);
       $pagesStmt->bindParam(2, $perPage, PDO::PARAM_INT);
       $pagesStmt->execute();
       $pages = $pagesStmt->fetchAll(PDO::FETCH_ASSOC);
   }

   // Обработка уведомлений
   $notification = null;
   if (isset($_SESSION['notification'])) {
       $notification = $_SESSION['notification'];
       unset($_SESSION['notification']);
   }

   $pageTitle = $site ? 'Pages - ' . htmlspecialchars($site['domain']) : 'All Pages';

} catch (Exception $e) {
   error_log("Pages list error: " . $e->getMessage());
   $error = "System error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
   <meta charset="UTF-8">
   <meta name="viewport" content="width=device-width, initial-scale=1.0">
   <title><?php echo $pageTitle; ?> - PBN Admin</title>
   <!-- Bootstrap CSS (from CDN) -->
   <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
   <!-- Font Awesome (from CDN) -->
   <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
   <!-- Custom CSS -->
   <style>
       body {
           font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
           line-height: 1.6;
           background: #f5f5f5;
           margin: 0;
           padding: 0;
       }
       .navbar {
           background-color: #2c3e50 !important;
           padding: 0.5rem 1rem;
       }
       .navbar-brand {
           color: white !important;
           font-weight: bold;
           font-size: 1.5rem;
       }
       .nav-link {
           color: rgba(255,255,255,0.8) !important;
       }
       .nav-link:hover, .nav-link.active {
           color: white !important;
       }
       .card {
           box-shadow: 0 2px 5px rgba(0,0,0,0.1);
           border: none;
           margin-bottom: 20px;
       }
       footer {
           margin-top: 3rem;
           padding: 1.5rem 0;
           background: #f8f9fa;
           border-top: 1px solid #e9ecef;
       }
       .pagination {
           justify-content: center;
       }
       .actions .btn {
           margin-right: 5px;
       }
       .page-url {
           max-width: 300px;
           white-space: nowrap;
           overflow: hidden;
           text-overflow: ellipsis;
           display: block;
       }
       .system-badge {
           cursor: help;
       }
       .title-column {
           min-width: 200px;
       }
   </style>
</head>
<body>
   <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
       <div class="container-fluid">
           <a class="navbar-brand" href="/pbns2/admin/">PBN Admin</a>
           <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
               <span class="navbar-toggler-icon"></span>
           </button>
           <div class="collapse navbar-collapse" id="navbarNav">
               <ul class="navbar-nav">
                   <li class="nav-item">
                       <a class="nav-link" href="/pbns2/admin/">
                           <i class="fas fa-tachometer-alt"></i> Dashboard
                       </a>
                   </li>
                   <li class="nav-item">
                       <a class="nav-link" href="sites.php">
                           <i class="fas fa-globe"></i> Sites
                       </a>
                   </li>
                   <li class="nav-item">
                       <a class="nav-link active" href="pages.php">
                           <i class="fas fa-file-alt"></i> Pages
                       </a>
                   </li>
                   <li class="nav-item">
                       <a class="nav-link" href="components.php">
                           <i class="fas fa-puzzle-piece"></i> Components
                       </a>
                   </li>
               </ul>
               <ul class="navbar-nav ms-auto">
                   <li class="nav-item dropdown">
                       <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                           <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                       </a>
                       <ul class="dropdown-menu dropdown-menu-end">
                           <li>
                               <a class="dropdown-item" href="#">
                                   <i class="fas fa-user-cog"></i> Profile
                               </a>
                           </li>
                           <li><hr class="dropdown-divider"></li>
                           <li>
                               <a class="dropdown-item" href="logout.php">
                                   <i class="fas fa-sign-out-alt"></i> Logout
                               </a>
                           </li>
                       </ul>
                   </li>
               </ul>
           </div>
       </div>
   </nav>
   
   <div class="container-fluid mt-4">
       <div class="d-flex justify-content-between align-items-center mb-4">
           <div>
               <h1>
                   <?php if ($site): ?>
                       Pages for <?php echo htmlspecialchars($site['domain']); ?>
                   <?php else: ?>
                       All Pages
                   <?php endif; ?>
               </h1>
               <?php if ($site): ?>
                   <nav aria-label="breadcrumb">
                       <ol class="breadcrumb">
                           <li class="breadcrumb-item"><a href="sites.php">Sites</a></li>
                           <li class="breadcrumb-item active"><?php echo htmlspecialchars($site['domain']); ?></li>
                       </ol>
                   </nav>
               <?php endif; ?>
           </div>
           
           <?php if ($site): ?>
               <a href="page-create.php?site_id=<?php echo $site['id']; ?>" class="btn btn-primary">
                   <i class="fas fa-plus"></i> Create New Page
               </a>
           <?php endif; ?>
       </div>
       
       <?php if (isset($notification)): ?>
           <div class="alert alert-<?php echo $notification['type']; ?> alert-dismissible fade show">
               <?php echo $notification['message']; ?>
               <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
           </div>
       <?php endif; ?>
       
       <?php if (isset($error)): ?>
           <div class="alert alert-danger">
               <?php echo $error; ?>
           </div>
       <?php endif; ?>
       
       <div class="card">
           <div class="card-header d-flex justify-content-between align-items-center">
               <h5 class="mb-0">
                   <?php if ($site): ?>
                       Pages (<?php echo $totalRecords; ?>)
                   <?php else: ?>
                       All Pages (<?php echo $totalRecords; ?>)
                   <?php endif; ?>
               </h5>
               
               <?php if (!$site): ?>
                   <div>
                       <form action="pages.php" method="get" class="d-flex">
                           <select name="site_id" class="form-select me-2" onchange="this.form.submit()">
                               <option value="">-- All Sites --</option>
                               <?php 
                               $sitesStmt = $db->query("SELECT id, domain FROM sites ORDER BY domain");
                               while ($siteOption = $sitesStmt->fetch(PDO::FETCH_ASSOC)): 
                               ?>
                                   <option value="<?php echo $siteOption['id']; ?>">
                                       <?php echo htmlspecialchars($siteOption['domain']); ?>
                                   </option>
                               <?php endwhile; ?>
                           </select>
                           <button type="submit" class="btn btn-outline-primary">Filter</button>
                       </form>
                   </div>
               <?php endif; ?>
           </div>
           <div class="card-body">
               <?php if (empty($pages)): ?>
                   <div class="alert alert-info">
                       <?php if ($site): ?>
                           No pages found for this site. Use the "Create New Page" button to add your first page.
                       <?php else: ?>
                           No pages found in the system.
                       <?php endif; ?>
                   </div>
               <?php else: ?>
                   <div class="table-responsive">
                       <table class="table table-striped table-hover">
                           <thead>
                               <tr>
                                   <th>ID</th>
                                   <?php if (!$site): ?>
                                       <th>Site</th>
                                   <?php endif; ?>
                                   <th class="title-column">Title</th>
                                   <th>URL</th>
                                   <th>Type</th>
                                   <th>Created</th>
                                   <th>Updated</th>
                                   <th>Actions</th>
                               </tr>
                           </thead>
                           <tbody>
                               <?php foreach ($pages as $page): ?>
                                   <tr>
                                       <td><?php echo $page['id']; ?></td>
                                       <?php if (!$site): ?>
                                           <td>
                                               <a href="pages.php?site_id=<?php echo $page['site_id']; ?>">
                                                   <?php echo htmlspecialchars($page['domain']); ?>
                                               </a>
                                           </td>
                                       <?php endif; ?>
                                       <td class="title-column"><?php echo htmlspecialchars($page['title']); ?></td>
                                       <td>
                                           <span class="page-url" title="<?php echo htmlspecialchars($page['slug']); ?>">
                                               <a href="//<?php echo htmlspecialchars($page['domain']); ?>/<?php echo htmlspecialchars($page['slug']); ?>" 
                                                  target="_blank">
                                                   /<?php echo htmlspecialchars($page['slug']); ?>
                                                   <i class="fas fa-external-link-alt fa-xs"></i>
                                               </a>
                                           </span>
                                       </td>
                                       <td>
                                           <?php if ($page['is_system']): ?>
                                               <span class="badge bg-info system-badge" title="System pages are required for site functionality">
                                                   System
                                               </span>
                                           <?php else: ?>
                                               <span class="badge bg-secondary">Regular</span>
                                           <?php endif; ?>
                                       </td>
                                       <td><?php echo date('Y-m-d', strtotime($page['created_at'])); ?></td>
                                       <td><?php echo date('Y-m-d', strtotime($page['updated_at'])); ?></td>
                                       <td class="actions">
                                           <div class="btn-group">
                                               <a href="page-edit.php?id=<?php echo $page['id']; ?>&site_id=<?php echo $page['site_id']; ?>" 
                                                   class="btn btn-sm btn-primary" title="Edit">
                                                    <i class="fas fa-edit"></i>
                                                </a>
                                               
                                               <button type="button" 
                                                       class="btn btn-sm btn-danger delete-page" 
                                                       data-bs-toggle="modal" 
                                                       data-bs-target="#deleteModal"
                                                       data-page-id="<?php echo $page['id']; ?>"
                                                       data-page-title="<?php echo htmlspecialchars($page['title']); ?>"
                                                       data-is-system="<?php echo $page['is_system']; ?>"
                                                       data-site-id="<?php echo $page['site_id']; ?>" 
                                                       title="Delete" 
                                                       <?php echo $page['is_system'] ? 'disabled' : ''; ?>>
                                                   <i class="fas fa-trash-alt"></i>
                                               </button>
                                           </div>
                                       </td>
                                   </tr>
                               <?php endforeach; ?>
                           </tbody>
                       </table>
                   </div>
                   
                   <?php if ($totalPages > 1): ?>
                       <nav aria-label="Page navigation" class="mt-4">
                           <ul class="pagination">
                               <li class="page-item <?php echo ($page <= 1) ? 'disabled' : ''; ?>">
                                   <a class="page-link" href="<?php echo ($page <= 1) ? '#' : '?page=' . ($page - 1) . ($siteId ? '&site_id=' . $siteId : ''); ?>" aria-label="Previous">
                                       <span aria-hidden="true">&laquo;</span>
                                   </a>
                               </li>
                               
                               <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                                   <li class="page-item <?php echo ($page == $i) ? 'active' : ''; ?>">
                                       <a class="page-link" href="?page=<?php echo $i . ($siteId ? '&site_id=' . $siteId : ''); ?>">
                                           <?php echo $i; ?>
                                       </a>
                                   </li>
                               <?php endfor; ?>
                               
                               <li class="page-item <?php echo ($page >= $totalPages) ? 'disabled' : ''; ?>">
                                   <a class="page-link" href="<?php echo ($page >= $totalPages) ? '#' : '?page=' . ($page + 1) . ($siteId ? '&site_id=' . $siteId : ''); ?>" aria-label="Next">
                                       <span aria-hidden="true">&raquo;</span>
                                   </a>
                               </li>
                           </ul>
                       </nav>
                   <?php endif; ?>
               <?php endif; ?>
           </div>
       </div>
   </div>
   
   <!-- Delete Modal -->
   <div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
       <div class="modal-dialog">
           <div class="modal-content">
               <div class="modal-header">
                   <h5 class="modal-title" id="deleteModalLabel">Confirm Delete</h5>
                   <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
               </div>
               <div class="modal-body">
                   Are you sure you want to delete the page <strong id="pageTitle"></strong>? This action cannot be undone.
                   <div id="systemWarning" class="alert alert-warning mt-3 d-none">
                       <i class="fas fa-exclamation-triangle"></i> You cannot delete system pages.
                   </div>
               </div>
               <div class="modal-footer">
                   <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                   <form id="deleteForm" action="page-delete.php" method="post">
                    <input type="hidden" id="pageIdInput" name="page_id" value="">
                    <input type="hidden" id="siteIdInput" name="site_id" value="<?php echo $siteId; ?>">
                    <button type="submit" class="btn btn-danger" id="deleteButton">Delete</button>
                </form>
               </div>
           </div>
       </div>
   </div>
   
   <footer class="text-center text-muted">
       <div class="container">
           <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
       </div>
   </footer>
   
   <!-- Bootstrap Bundle with Popper (from CDN) -->
   <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
   <script>
   document.addEventListener('DOMContentLoaded', function() {
       // Setup for delete modal
       const deleteModal = document.getElementById('deleteModal');
       if (deleteModal) {
           deleteModal.addEventListener('show.bs.modal', function(event) {
               const button = event.relatedTarget;
               const pageId = button.getAttribute('data-page-id');
               const pageTitle = button.getAttribute('data-page-title');
               const isSystem = button.getAttribute('data-is-system') === '1';
               
               document.getElementById('pageIdInput').value = pageId;
               document.getElementById('pageTitle').textContent = pageTitle;
               
               // Handle system pages (cannot be deleted)
               const systemWarning = document.getElementById('systemWarning');
               const deleteButton = document.getElementById('deleteButton');
               
               if (isSystem) {
                   systemWarning.classList.remove('d-none');
                   deleteButton.disabled = true;
               } else {
                   systemWarning.classList.add('d-none');
                   deleteButton.disabled = false;
               }
           });
       }
   });
   </script>
</body>
</html>