<?php

require_once __DIR__ . '/../config/config.php';
// Включаем отображение всех ошибок
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Регистрируем обработчик ошибок
function my_error_handler($errno, $errstr, $errfile, $errline) {
    $error_message = "Error [$errno] $errstr in $errfile on line $errline";
    error_log($error_message);
    echo "<div style='color:red;'>$error_message</div>";
}
set_error_handler('my_error_handler');

// admin/site-create.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы

require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';
require_once __DIR__ . '/../includes/SiteManager.php';  // Добавлено
require_once __DIR__ . '/../includes/ApacheManager.php'; // Добавлено

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем AuthManager и SiteManager
    $authManager = new AuthManager($db);
    $siteManager = new SiteManager($db); // Добавлено
    $logger = new SystemLogger($db); // Добавлено

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя
    $currentUser = $authManager->getCurrentUser();

    // Обработка формы создания сайта
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $domain = $_POST['domain'] ?? '';
        $title = $_POST['title'] ?? '';
        $active = isset($_POST['active']) ? 1 : 0;
        $ssl_enabled = isset($_POST['ssl_enabled']) ? 1 : 0;
        $cloudflare_enabled = isset($_POST['cloudflare_enabled']) ? 1 : 0;
        
        // Валидация
        $errors = [];
        if (empty($domain)) {
            $errors[] = "Domain is required";
        } elseif (!preg_match('/^([a-zA-Z0-9]([a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z]{2,}$/', $domain)) {
            $errors[] = "Invalid domain format";
        }
        
        if (empty($title)) {
            $errors[] = "Title is required";
        }
        
        // Проверка на существование домена
        $checkStmt = $db->prepare("SELECT id FROM sites WHERE domain = ?");
        $checkStmt->execute([$domain]);
        if ($checkStmt->fetch()) {
            $errors[] = "Domain already exists";
        }
        
        // Проверяем права на директории
        $sitePath = SITES_BASE_PATH . '/' . $domain;
        if (!is_writable(dirname($sitePath))) {
            $errors[] = "Directory " . SITES_BASE_PATH . " is not writable. Check permissions.";
            $logger->log(0, 'site_creation', "Directory " . SITES_BASE_PATH . " is not writable", 'error');
        }

        if (empty($errors)) {
            try {
                // Начинаем транзакцию
                $db->beginTransaction();
                
                // Вставка нового сайта
                $stmt = $db->prepare("
                    INSERT INTO sites (domain, title, active, ssl_enabled, cloudflare_enabled)
                    VALUES (?, ?, ?, ?, ?)
                ");
                $stmt->execute([$domain, $title, $active, $ssl_enabled, $cloudflare_enabled]);
                $siteId = $db->lastInsertId();
                
                // Создание базовых страниц
                $homePageStmt = $db->prepare("
                    INSERT INTO pages (site_id, title, slug, content, h1, meta_title, is_system)
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");
                $homePageStmt->execute([
                    $siteId,
                    'Home',
                    'home',
                    '<h1>Welcome to ' . htmlspecialchars($title) . '</h1><p>This is the homepage of your new website.</p>',
                    'Welcome to ' . htmlspecialchars($title),
                    htmlspecialchars($title) . ' - Home Page',
                    1
                ]);
                
                $notFoundPageStmt = $db->prepare("
                    INSERT INTO pages (site_id, title, slug, content, h1, meta_title, is_system)
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");
                $notFoundPageStmt->execute([
                    $siteId,
                    '404 Not Found',
                    '404',
                    '<h1>Page Not Found</h1><p>The page you are looking for could not be found.</p>',
                    'Page Not Found',
                    '404 Not Found',
                    1
                ]);
                
                // Создание базовых компонентов
                $headerStmt = $db->prepare("
                    INSERT INTO components (site_id, name, type, content, is_active)
                    VALUES (?, ?, ?, ?, ?)
                ");
                $headerStmt->execute([
                    $siteId,
                    'Default Header',
                    'header',
                    '<header class="site-header"><div class="container"><div class="logo"><a href="/">' . htmlspecialchars($title) . '</a></div><nav>{menu}</nav></div></header>',
                    1
                ]);
                
                $footerStmt = $db->prepare("
                    INSERT INTO components (site_id, name, type, content, is_active)
                    VALUES (?, ?, ?, ?, ?)
                ");
                $footerStmt->execute([
                    $siteId,
                    'Default Footer',
                    'footer',
                    '<footer class="site-footer"><div class="container"><p>&copy; ' . date('Y') . ' ' . htmlspecialchars($title) . '. All rights reserved.</p></div></footer>',
                    1
                ]);

                // Создаем физическую структуру сайта
                try {
                    // Создаем директорию для сайта
                    if (!file_exists($sitePath)) {
                        if (!mkdir($sitePath, 0755, true)) {
                            throw new Exception("Failed to create site directory: $sitePath");
                        }
                        $logger->log($siteId, 'site_creation', "Directory created: $sitePath", 'success');
                    }
                    
                    // Копируем шаблонные файлы
                    if (file_exists(TEMPLATES_PATH . '/index.template.php')) {
                        if (!copy(TEMPLATES_PATH . '/index.template.php', $sitePath . '/index.php')) {
                            throw new Exception("Failed to copy index template to: $sitePath/index.php");
                        }
                        $logger->log($siteId, 'site_creation', "Index file created", 'success');
                    } else {
                        throw new Exception("Template file not found: " . TEMPLATES_PATH . '/index.template.php');
                    }
                    
                    // Создаем .htaccess файл
                    $htaccessContent = "RewriteEngine On\nRewriteBase /\n";
                    $htaccessContent .= "RewriteCond %{REQUEST_FILENAME} !-f\n";
                    $htaccessContent .= "RewriteCond %{REQUEST_FILENAME} !-d\n";
                    $htaccessContent .= "RewriteRule ^(.*)$ index.php [L,QSA]\n";
                    
                    if (!file_put_contents($sitePath . '/.htaccess', $htaccessContent)) {
                        throw new Exception("Failed to create .htaccess file");
                    }
                    $logger->log($siteId, 'site_creation', "Htaccess file created", 'success');
                    
                    // Создаем локальный config.php
                    $configContent = "<?php\ndefine('SITE_ID', $siteId);\n";
                    $configContent .= "define('DB_HOST', '" . DB_HOST . "');\n";
                    $configContent .= "define('DB_NAME', '" . DB_NAME . "');\n";
                    $configContent .= "define('DB_USER', '" . DB_USER . "');\n";
                    $configContent .= "define('DB_PASS', '" . DB_PASS . "');\n";
                    
                    if (!file_put_contents($sitePath . '/config.php', $configContent)) {
                        throw new Exception("Failed to create config.php file");
                    }
                    $logger->log($siteId, 'site_creation', "Config file created", 'success');
                    
                    // Пытаемся создать конфиг Apache, если есть нужные права
                    try {
                        $apacheManager = new ApacheManager();
                        $apacheManager->createConfig($domain, $sitePath);
                        $logger->log($siteId, 'site_creation', "Apache configuration created", 'success');
                    } catch (Exception $e) {
                        // Логируем ошибку, но не прерываем процесс создания сайта
                        $logger->log($siteId, 'site_creation', "Apache configuration failed: " . $e->getMessage(), 'warning');
                        // Добавляем инструкцию в уведомление
                        $_SESSION['notification'] = [
                            'type' => 'warning',
                            'message' => "Site '{$title}' created, but Apache configuration requires manual setup: " . $e->getMessage()
                        ];
                    }
                    
                    // Завершаем транзакцию
                    $db->commit();
                    
                    // Если нет отдельного предупреждения, устанавливаем стандартное сообщение об успехе
                    if (!isset($_SESSION['notification'])) {
                        $_SESSION['notification'] = [
                            'type' => 'success',
                            'message' => "Site '{$title}' created successfully!"
                        ];
                    }
                    
                    // Перенаправляем на страницу сайтов
                    header('Location: sites.php');
                    exit;
                    
                } catch (Exception $e) {
                    $db->rollBack();
                    $errors[] = $e->getMessage();
                    $logger->log($siteId, 'site_creation', $e->getMessage(), 'error');
                }
            } catch (Exception $e) {
                $db->rollBack();
                $errors[] = $e->getMessage();
                $logger->log(0, 'site_creation', $e->getMessage(), 'error');
            }
        }
    }
    
    $pageTitle = 'Create New Site';

} catch (Exception $e) {
    $errors[] = "System error: " . $e->getMessage();
    error_log("Site creation error: " . $e->getMessage());
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - PBN Admin</title>
    <!-- Bootstrap CSS (from CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome (from CDN) -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            background: #f5f5f5;
            margin: 0;
            padding: 0;
        }
        .navbar {
            background-color: #2c3e50 !important;
            padding: 0.5rem 1rem;
        }
        .navbar-brand {
            color: white !important;
            font-weight: bold;
            font-size: 1.5rem;
        }
        .nav-link {
            color: rgba(255,255,255,0.8) !important;
        }
        .nav-link:hover, .nav-link.active {
            color: white !important;
        }
        .card {
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            border: none;
            margin-bottom: 20px;
        }
        footer {
            margin-top: 3rem;
            padding: 1.5rem 0;
            background: #f8f9fa;
            border-top: 1px solid #e9ecef;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand" href="index.php">PBN Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="index.php">
                            <i class="fas fa-tachometer-alt"></i> Dashboard
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="sites.php">
                            <i class="fas fa-globe"></i> Sites
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="pages.php">
                            <i class="fas fa-file-alt"></i> Pages
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="components.php">
                            <i class="fas fa-puzzle-piece"></i> Components
                        </a>
                    </li>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                            <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user-cog"></i> Profile
                                </a>
                            </li>
                            <li><hr class="dropdown-divider"></li>
                            <li>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt"></i> Logout
                                </a>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
    
    <div class="container-fluid mt-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1>Create New Site</h1>
            <a href="sites.php" class="btn btn-secondary">
                <i class="fas fa-arrow-left"></i> Back to Sites
            </a>
        </div>
        
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <h5><i class="fas fa-exclamation-triangle"></i> Error</h5>
                <ul class="mb-0">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo htmlspecialchars($error); ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <div class="card">
            <div class="card-body">
                <form method="post" action="site-create.php">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="domain" class="form-label">Domain *</label>
                            <input type="text" class="form-control" id="domain" name="domain" 
                                   value="<?php echo htmlspecialchars($_POST['domain'] ?? ''); ?>" required>
                            <div class="form-text">Enter domain without http/https (e.g., example.com)</div>
                        </div>
                        
                        <div class="col-md-6">
                            <label for="title" class="form-label">Site Title *</label>
                            <input type="text" class="form-control" id="title" name="title" 
                                   value="<?php echo htmlspecialchars($_POST['title'] ?? ''); ?>" required>
                        </div>
                    </div>
                    
                    <div class="row mb-4">
                        <div class="col-md-4">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="active" name="active" 
                                       <?php echo isset($_POST['active']) || !isset($_POST) ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="active">Site Active</label>
                            </div>
                        </div>
                        
                        <div class="col-md-4">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="ssl_enabled" name="ssl_enabled" 
                                       <?php echo isset($_POST['ssl_enabled']) || !isset($_POST) ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="ssl_enabled">Enable SSL</label>
                            </div>
                        </div>
                        
                        <div class="col-md-4">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="cloudflare_enabled" name="cloudflare_enabled" 
                                       <?php echo isset($_POST['cloudflare_enabled']) || !isset($_POST) ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="cloudflare_enabled">Enable CloudFlare</label>
                            </div>
                        </div>
                    </div>
                    
                    <div class="alert alert-info">
                        <h5><i class="fas fa-info-circle"></i> Note</h5>
                        <p>Creating a new site will automatically:</p>
                        <ul>
                            <li>Create basic pages (Home and 404)</li>
                            <li>Set up default header and footer components</li>
                            <li>Configure basic site settings</li>
                        </ul>
                        <p class="mb-0">You can customize all these items after creation.</p>
                    </div>
                    
                    <div class="d-flex justify-content-between mt-4">
                        <a href="sites.php" class="btn btn-secondary">Cancel</a>
                        <button type="submit" class="btn btn-primary">Create Site</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <footer class="text-center text-muted">
        <div class="container">
            <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Bootstrap Bundle with Popper (from CDN) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // Функция автоматического создания слага из домена
        const domainInput = document.getElementById('domain');
        const titleInput = document.getElementById('title');
        
        if (domainInput && titleInput) {
            domainInput.addEventListener('blur', function() {
                if (domainInput.value && !titleInput.value) {
                    // Если домен введен, а заголовок нет, автоматически заполняем заголовок
                    const domain = domainInput.value;
                    const title = domain.split('.')[0]; // Берем первую часть домена
                    titleInput.value = title.charAt(0).toUpperCase() + title.slice(1); // Делаем первую букву заглавной
                }
            });
        }
    });
    </script>
</body>
</html>