<?php
// admin/site-delete.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем AuthManager
    $authManager = new AuthManager($db);

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя и проверяем права (только администратор может удалять сайты)
    $currentUser = $authManager->getCurrentUser();
    if ($currentUser['role'] !== 'administrator') {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'You do not have permission to delete sites.'
        ];
        header('Location: sites.php');
        exit;
    }

    // Проверяем метод запроса и наличие site_id
    if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['site_id'])) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Invalid request.'
        ];
        header('Location: sites.php');
        exit;
    }

    $siteId = (int)$_POST['site_id'];

    // Получаем информацию о сайте перед удалением для лога
    $siteStmt = $db->prepare("SELECT domain FROM sites WHERE id = ?");
    $siteStmt->execute([$siteId]);
    $site = $siteStmt->fetch(PDO::FETCH_ASSOC);

    if (!$site) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Site not found.'
        ];
        header('Location: sites.php');
        exit;
    }

    // Начинаем транзакцию
    $db->beginTransaction();

    try {
        // Удаляем все связанные записи (компоненты, страницы, настройки, редиректы)
        $tables = ['components', 'pages', 'site_settings', 'redirects', 'system_logs'];
        
        foreach ($tables as $table) {
            $stmt = $db->prepare("DELETE FROM {$table} WHERE site_id = ?");
            $stmt->execute([$siteId]);
        }

        // Удаляем сам сайт
        $stmt = $db->prepare("DELETE FROM sites WHERE id = ?");
        $stmt->execute([$siteId]);

        // Коммитим транзакцию
        $db->commit();

        // Логируем удаление
        $logger = new SystemLogger($db);
        $logger->log(null, 'site_deleted', "Site '{$site['domain']}' (ID: {$siteId}) was deleted by {$currentUser['username']}", 'info');

        $_SESSION['notification'] = [
            'type' => 'success',
            'message' => "Site '{$site['domain']}' has been successfully deleted."
        ];
    } catch (Exception $e) {
        // Откатываем транзакцию в случае ошибки
        $db->rollBack();
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => "Error deleting site: " . $e->getMessage()
        ];
    }

    // Перенаправляем обратно на страницу сайтов
    header('Location: sites.php');
    exit;

} catch (Exception $e) {
    $_SESSION['notification'] = [
        'type' => 'danger',
        'message' => "System error: " . $e->getMessage()
    ];
    header('Location: sites.php');
    exit;
}