<?php
// admin/site-edit.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем AuthManager
    $authManager = new AuthManager($db);

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя
    $currentUser = $authManager->getCurrentUser();

    // Получаем ID сайта
    $siteId = isset($_GET['id']) ? (int)$_GET['id'] : null;
    
    if (!$siteId) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Site ID is required'
        ];
        header('Location: sites.php');
        exit;
    }

    // Получаем информацию о сайте
    $stmt = $db->prepare("SELECT * FROM sites WHERE id = :id");
    $stmt->bindValue(':id', $siteId, PDO::PARAM_INT);
    $stmt->execute();
    $site = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$site) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Site not found'
        ];
        header('Location: sites.php');
        exit;
    }

    // Обработка формы редактирования
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $title = trim($_POST['title'] ?? '');
        $active = isset($_POST['active']) ? 1 : 0;
        $sslEnabled = isset($_POST['ssl_enabled']) ? 1 : 0;
        $cloudflareEnabled = isset($_POST['cloudflare_enabled']) ? 1 : 0;
        
        // Валидация
        $errors = [];
        if (empty($title)) {
            $errors[] = "Title is required";
        }
        
        if (empty($errors)) {
            // Обновляем сайт
            $updateStmt = $db->prepare("
                UPDATE sites 
                SET 
                    title = :title,
                    active = :active,
                    ssl_enabled = :ssl_enabled,
                    cloudflare_enabled = :cloudflare_enabled,
                    updated_at = CURRENT_TIMESTAMP
                WHERE id = :id
            ");
            
            $updateStmt->bindValue(':title', $title, PDO::PARAM_STR);
            $updateStmt->bindValue(':active', $active, PDO::PARAM_INT);
            $updateStmt->bindValue(':ssl_enabled', $sslEnabled, PDO::PARAM_INT);
            $updateStmt->bindValue(':cloudflare_enabled', $cloudflareEnabled, PDO::PARAM_INT);
            $updateStmt->bindValue(':id', $siteId, PDO::PARAM_INT);
            $updateStmt->execute();
            
            // Логируем обновление
            $logger = new SystemLogger($db);
            $logger->log(
                $siteId,
                'site_updated',
                "Site '{$site['domain']}' updated by {$currentUser['username']}",
                'success'
            );
            
            $_SESSION['notification'] = [
                'type' => 'success',
                'message' => "Site '{$site['domain']}' has been successfully updated"
            ];
            
            // Перенаправляем на страницу сайтов
            header('Location: sites.php');
            exit;
        }
    }

    $pageTitle = 'Edit Site - ' . htmlspecialchars($site['domain']);

} catch (Exception $e) {
    error_log("Site edit error: " . $e->getMessage());
    $error = "System error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - PBN Admin</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            background: #f5f5f5;
            margin: 0;
            padding: 0;
        }
        .navbar {
            background-color: #2c3e50 !important;
            padding: 0.5rem 1rem;
        }
        .navbar-brand {
            color: white !important;
            font-weight: bold;
            font-size: 1.5rem;
        }
        .nav-link {
            color: rgba(255,255,255,0.8) !important;
        }
        .nav-link:hover, .nav-link.active {
            color: white !important;
        }
        .card {
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            border: none;
            margin-bottom: 20px;
        }
        footer {
            margin-top: 3rem;
            padding: 1.5rem 0;
            background: #f8f9fa;
            border-top: 1px solid #e9ecef;
        }
    </style>
</head>
<body>
    <?php include 'templates/navbar.php'; ?>
    
    <div class="container-fluid mt-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                <h1>Edit Site</h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="sites.php">Sites</a></li>
                        <li class="breadcrumb-item active"><?php echo htmlspecialchars($site['domain']); ?></li>
                    </ol>
                </nav>
            </div>
            
            <a href="sites.php" class="btn btn-secondary">
                <i class="fas fa-arrow-left"></i> Back to Sites
            </a>
        </div>
        
        <?php if (isset($error)): ?>
            <div class="alert alert-danger">
                <?php echo $error; ?>
            </div>
        <?php endif; ?>
        
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <h5><i class="fas fa-exclamation-circle"></i> Validation Errors</h5>
                <ul class="mb-0">
                    <?php foreach ($errors as $errMsg): ?>
                        <li><?php echo htmlspecialchars($errMsg); ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        
        <div class="card">
            <div class="card-body">
                <form method="post" action="site-edit.php?id=<?php echo $siteId; ?>">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="domain" class="form-label">Domain</label>
                            <input type="text" class="form-control" id="domain" 
                                   value="<?php echo htmlspecialchars($site['domain']); ?>" readonly>
                            <div class="form-text">Domain cannot be changed after site creation</div>
                        </div>
                        
                        <div class="col-md-6">
                            <label for="title" class="form-label">Site Title *</label>
                            <input type="text" class="form-control" id="title" name="title" 
                                   value="<?php echo htmlspecialchars($site['title']); ?>" required>
                        </div>
                    </div>
                    
                    <div class="row mb-4">
                        <div class="col-md-4">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="active" name="active" 
                                       <?php echo $site['active'] ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="active">Site Active</label>
                                <div class="form-text">
                                    Inactive sites will return a 404 error when accessed
                                </div>
                            </div>
                        </div>
                        
                        <div class="col-md-4">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="ssl_enabled" name="ssl_enabled" 
                                       <?php echo $site['ssl_enabled'] ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="ssl_enabled">Enable SSL</label>
                                <div class="form-text">
                                    Uses Let's Encrypt for free SSL certificates
                                </div>
                            </div>
                        </div>
                        
                        <div class="col-md-4">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" id="cloudflare_enabled" name="cloudflare_enabled" 
                                       <?php echo $site['cloudflare_enabled'] ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="cloudflare_enabled">Enable CloudFlare</label>
                                <div class="form-text">
                                    Use CloudFlare CDN and DDoS protection
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="d-flex justify-content-between">
                        <a href="sites.php" class="btn btn-secondary">Cancel</a>
                        <button type="submit" class="btn btn-primary">Update Site</button>
                    </div>
                </form>
            </div>
        </div>
        
        <!-- Advanced Options Section -->
        <div class="card mt-4">
            <div class="card-header">
                <h5 class="mb-0">Advanced Options</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4 mb-3">
                        <div class="card h-100">
                            <div class="card-body">
                                <h5 class="card-title">
                                    <i class="fas fa-server text-primary"></i> 
                                    Apache Configuration
                                </h5>
                                <p class="card-text">Regenerate Apache configuration files for this site.</p>
                                <div class="d-grid">
                                    <button type="button" class="btn btn-outline-primary">
                                        <i class="fas fa-sync-alt"></i> Rebuild Config
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="col-md-4 mb-3">
                        <div class="card h-100">
                            <div class="card-body">
                                <h5 class="card-title">
                                    <i class="fas fa-shield-alt text-success"></i>
                                    SSL Certificate
                                </h5>
                                <p class="card-text">Manually trigger SSL certificate renewal.</p>
                                <div class="d-grid">
                                    <button type="button" class="btn btn-outline-success">
                                        <i class="fas fa-lock"></i> Renew SSL
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="col-md-4 mb-3">
                        <div class="card h-100">
                            <div class="card-body">
                                <h5 class="card-title">
                                    <i class="fas fa-cloud text-info"></i>
                                    CloudFlare
                                </h5>
                                <p class="card-text">Update DNS records and cache settings.</p>
                                <div class="d-grid">
                                    <button type="button" class="btn btn-outline-info">
                                        <i class="fas fa-sync-alt"></i> Update CloudFlare
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <footer class="text-center text-muted">
        <div class="container">
            <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
        </div>
    </footer>
    
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>