<?php
// includes/ApacheManager.php
class ApacheManager {
    private $sitesAvailable = '/etc/apache2/sites-available/';
    private $sitesEnabled = '/etc/apache2/sites-enabled/';
    private $logger;
    
    public function __construct() {
        $this->logger = new SystemLogger(get_db_connection());
    }
    
    public function createConfig($domain, $path) {
        $configContent = $this->generateVirtualHost($domain, $path);
        $configFile = $this->sitesAvailable . $domain . '.conf';
        
        // Проверяем права доступа к директории sites-available
        if (!is_writable($this->sitesAvailable)) {
            // Если нет прав, создаем конфиг во временной директории
            $tempConfigPath = sys_get_temp_dir() . '/' . $domain . '.conf';
            file_put_contents($tempConfigPath, $configContent);
            
            $this->logger->log(0, 'apache_config', "Apache config created at $tempConfigPath. Manual installation required.", 'warning');
            
            // Добавляем инструкции для ручной установки
            throw new Exception("Cannot write to Apache config directory. A configuration file has been created at: $tempConfigPath. Please manually install it using sudo.");
        }
        
        // Создаем конфиг
        if (!file_put_contents($configFile, $configContent)) {
            throw new Exception("Failed to create Apache config: Permission denied");
        }
        
        // Включаем сайт
        try {
            $this->enableSite($domain);
        } catch (Exception $e) {
            $this->logger->log(0, 'apache_config', "Failed to enable site: " . $e->getMessage(), 'warning');
            throw new Exception("Config created but failed to enable site: " . $e->getMessage());
        }
        
        // Проверяем конфигурацию
        if (!$this->testConfig()) {
            // Если тест не прошел, удаляем созданный конфиг
            if (file_exists($this->sitesEnabled . $domain . '.conf')) {
                unlink($this->sitesEnabled . $domain . '.conf');
            }
            if (file_exists($configFile)) {
                unlink($configFile);
            }
            throw new Exception("Apache configuration test failed");
        }
        
        // Пытаемся перезагрузить Apache
        try {
            $this->reload();
        } catch (Exception $e) {
            $this->logger->log(0, 'apache_config', "Failed to reload Apache: " . $e->getMessage(), 'warning');
            throw new Exception("Config created and enabled, but Apache reload failed: " . $e->getMessage() . ". Manual reload required.");
        }
        
        return true;
    }
    
    private function generateVirtualHost($domain, $path) {
        // Убедимся, что путь существует и завершается без слеша
        $path = rtrim($path, '/');
        
        return <<<CONF
<VirtualHost *:80>
    ServerName {$domain}
    ServerAlias www.{$domain}
    DocumentRoot {$path}
    
    <Directory "{$path}">
        Options -Indexes +FollowSymLinks
        AllowOverride All
        Require all granted
    </Directory>
    
    # Логи в отдельную директорию для каждого домена
    ErrorLog \${APACHE_LOG_DIR}/{$domain}-error.log
    CustomLog \${APACHE_LOG_DIR}/{$domain}-access.log combined
    
    # PHP-FPM Configuration
    <FilesMatch \.php$>
        # Используем стандартный сокет PHP-FPM
        # Важно проверить правильный путь к сокету
        SetHandler "proxy:unix:/run/php/php8.1-fpm.sock|fcgi://localhost/"
    </FilesMatch>
    
    # Добавляем явное указание индексных файлов
    DirectoryIndex index.php index.html
</VirtualHost>
CONF;
    }
    
    private function enableSite($domain) {
        $source = $this->sitesAvailable . $domain . '.conf';
        $target = $this->sitesEnabled . $domain . '.conf';
        
        // Проверка на существование файла конфигурации
        if (!file_exists($source)) {
            throw new Exception("Apache config file not found: $source");
        }
        
        // Проверяем права на запись в sites-enabled
        if (!is_writable($this->sitesEnabled)) {
            throw new Exception("Cannot write to {$this->sitesEnabled}. Manual enabling required: sudo a2ensite {$domain}.conf");
        }
        
        // Удаляем симлинк, если он уже существует
        if (file_exists($target)) {
            if (!unlink($target)) {
                throw new Exception("Failed to remove existing symlink: $target");
            }
        }
        
        // Создаем новый симлинк
        if (!symlink($source, $target)) {
            throw new Exception("Failed to enable site: Could not create symlink");
        }
        
        return true;
    }
    
    private function testConfig() {
        // Проверяем возможность выполнения команды
        if (!function_exists('exec')) {
            $this->logger->log(0, 'apache_config', "Cannot test Apache config: exec function disabled", 'warning');
            return true; // Предполагаем, что конфиг правильный, если нельзя проверить
        }
        
        exec('apache2ctl configtest 2>&1', $output, $returnVar);
        if ($returnVar !== 0) {
            $this->logger->log(0, 'apache_config', "Apache config test failed: " . implode("\n", $output), 'error');
        }
        return ($returnVar === 0);
    }
    
    private function reload() {
        // Проверяем возможность выполнения команды
        if (!function_exists('exec')) {
            throw new Exception("Cannot reload Apache: exec function disabled. Manual reload required: sudo systemctl reload apache2");
        }
        
        // Пробуем через sudo
        $commands = [
            'sudo systemctl reload apache2',
            'sudo service apache2 reload',
            'systemctl reload apache2',
            'service apache2 reload'
        ];
        
        $success = false;
        $lastOutput = [];
        
        foreach ($commands as $command) {
            exec("$command 2>&1", $output, $returnVar);
            if ($returnVar === 0) {
                $success = true;
                break;
            }
            $lastOutput = $output;
        }
        
        if (!$success) {
            throw new Exception("Failed to reload Apache: " . implode("\n", $lastOutput));
        }
        
        return true;
    }
    
    // Добавляем метод для генерации файла конфигурации без установки
    public function generateConfigFile($domain, $path) {
        $configContent = $this->generateVirtualHost($domain, $path);
        $configFile = sys_get_temp_dir() . '/' . $domain . '.conf';
        
        if (file_put_contents($configFile, $configContent)) {
            return $configFile;
        } else {
            throw new Exception("Failed to create config file at: $configFile");
        }
    }
}