<?php
// includes/AuthManager.php
class AuthManager {
    private $db;
    private $logger;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->logger = new SystemLogger($db);
    }
    
    /**
     * Authenticate user
     */
    public function login($username, $password) {
        // Get user by username
        $stmt = $this->db->prepare("SELECT * FROM users WHERE username = ?");
        $stmt->execute([$username]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$user) {
            return false;
        }
        
        // Verify password
        if (!password_verify($password, $user['password_hash'])) {
            // Log failed login attempt
            $this->logger->log(null, 'login_failed', "Failed login attempt for user '{$username}'", 'warning');
            return false;
        }
        
        // Update last login time
        $stmt = $this->db->prepare("UPDATE users SET last_login = CURRENT_TIMESTAMP WHERE id = ?");
        $stmt->execute([$user['id']]);
        
        // Log successful login
        $this->logger->log(null, 'login_success', "User '{$username}' logged in", 'success');
        
        // Start session
        if (session_status() !== PHP_SESSION_ACTIVE) {
            session_start();
        }
        
        // Store user data in session
        $_SESSION['user'] = [
            'id' => $user['id'],
            'username' => $user['username'],
            'email' => $user['email'],
            'role' => $user['role'],
            'is_authenticated' => true,
            'login_time' => time()
        ];
        
        return true;
    }
    
    /**
     * Log out user
     */
    public function logout() {
        if (session_status() !== PHP_SESSION_ACTIVE) {
            session_start();
        }
        
        // Log logout
        if (isset($_SESSION['user'])) {
            $username = $_SESSION['user']['username'];
            $this->logger->log(null, 'logout', "User '{$username}' logged out", 'success');
        }
        
        // Clear session
        $_SESSION = [];
        
        // Destroy session cookie
        if (ini_get("session.use_cookies")) {
            $params = session_get_cookie_params();
            setcookie(
                session_name(),
                '',
                time() - 42000,
                $params["path"],
                $params["domain"],
                $params["secure"],
                $params["httponly"]
            );
        }
        
        // Destroy session
        session_destroy();
        
        return true;
    }
    
    /**
     * Check if user is authenticated
     */
    public function isAuthenticated() {
        if (session_status() !== PHP_SESSION_ACTIVE) {
            session_start();
        }
        
        return isset($_SESSION['user']) && $_SESSION['user']['is_authenticated'];
    }
    
    /**
     * Get current user
     */
    public function getCurrentUser() {
        if (!$this->isAuthenticated()) {
            return null;
        }
        
        return $_SESSION['user'];
    }
    
    /**
     * Check if user has required role
     */
    public function hasRole($requiredRole) {
        if (!$this->isAuthenticated()) {
            return false;
        }
        
        $userRole = $_SESSION['user']['role'];
        
        // Administrator has all permissions
        if ($userRole === 'administrator') {
            return true;
        }
        
        // Exact role match
        if ($userRole === $requiredRole) {
            return true;
        }
        
        return false;
    }
    
    /**
     * Create user
     */
    public function createUser($username, $email, $password, $role = 'editor') {
        try {
            // Check if username exists
            $stmt = $this->db->prepare("SELECT id FROM users WHERE username = ?");
            $stmt->execute([$username]);
            if ($stmt->fetch()) {
                throw new Exception("Username already exists");
            }
            
            // Check if email exists
            $stmt = $this->db->prepare("SELECT id FROM users WHERE email = ?");
            $stmt->execute([$email]);
            if ($stmt->fetch()) {
                throw new Exception("Email already exists");
            }
            
            // Create password hash
            $passwordHash = password_hash($password, PASSWORD_DEFAULT);
            
            // Insert user
            $stmt = $this->db->prepare("
                INSERT INTO users (username, email, password_hash, role)
                VALUES (?, ?, ?, ?)
            ");
            $stmt->execute([$username, $email, $passwordHash, $role]);
            
            $userId = $this->db->lastInsertId();
            $this->logger->log(null, 'user_created', "User '{$username}' created with role '{$role}'", 'success');
            
            return $userId;
            
        } catch (Exception $e) {
            $this->logger->log(null, 'user_creation_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Update user
     */
    public function updateUser($userId, $data) {
        try {
            // Get current user data
            $stmt = $this->db->prepare("SELECT * FROM users WHERE id = ?");
            $stmt->execute([$userId]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$user) {
                throw new Exception("User not found");
            }
            
            // Check if username is being changed and already exists
            if (isset($data['username']) && $data['username'] !== $user['username']) {
                $stmt = $this->db->prepare("SELECT id FROM users WHERE username = ? AND id != ?");
                $stmt->execute([$data['username'], $userId]);
                if ($stmt->fetch()) {
                    throw new Exception("Username already exists");
                }
            }
            
            // Check if email is being changed and already exists
            if (isset($data['email']) && $data['email'] !== $user['email']) {
                $stmt = $this->db->prepare("SELECT id FROM users WHERE email = ? AND id != ?");
                $stmt->execute([$data['email'], $userId]);
                if ($stmt->fetch()) {
                    throw new Exception("Email already exists");
                }
            }
            
            // Prepare update fields
            $updateFields = [];
            $params = [];
            
            if (isset($data['username'])) {
                $updateFields[] = "username = ?";
                $params[] = $data['username'];
            }
            
            if (isset($data['email'])) {
                $updateFields[] = "email = ?";
                $params[] = $data['email'];
            }
            
            if (isset($data['role'])) {
                $updateFields[] = "role = ?";
                $params[] = $data['role'];
            }
            
            if (isset($data['password'])) {
                $updateFields[] = "password_hash = ?";
                $params[] = password_hash($data['password'], PASSWORD_DEFAULT);
            }
            
            if (empty($updateFields)) {
                return true; // Nothing to update
            }
            
            // Add user ID to params
            $params[] = $userId;
            
            // Update user
            $sql = "UPDATE users SET " . implode(", ", $updateFields) . " WHERE id = ?";
            $stmt = $this->db->prepare($sql);
            $stmt->execute($params);
            
            $this->logger->log(null, 'user_updated', "User ID {$userId} updated", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log(null, 'user_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Delete user
     */
    public function deleteUser($userId) {
        try {
            // Check if user exists
            $stmt = $this->db->prepare("SELECT username FROM users WHERE id = ?");
            $stmt->execute([$userId]);
            $username = $stmt->fetchColumn();
            
            if (!$username) {
                throw new Exception("User not found");
            }
            
            // Delete user
            $stmt = $this->db->prepare("DELETE FROM users WHERE id = ?");
            $stmt->execute([$userId]);
            
            $this->logger->log(null, 'user_deleted', "User '{$username}' deleted", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log(null, 'user_deletion_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Get users
     */
    public function getUsers() {
        $stmt = $this->db->prepare("
            SELECT id, username, email, role, created_at, last_login 
            FROM users ORDER BY username
        ");
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Get user by ID
     */
    public function getUser($userId) {
        $stmt = $this->db->prepare("
            SELECT id, username, email, role, created_at, last_login 
            FROM users WHERE id = ?
        ");
        $stmt->execute([$userId]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
}