<?php
// includes/BackupManager.php
class BackupManager {
    private $db;
    private $logger;
    private $backupPath;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->logger = new SystemLogger($db);
        $this->backupPath = BACKUP_PATH;
    }
    
    /**
     * Create backup for a site
     */
    public function createSiteBackup($siteId) {
        try {
            // Get site info
            $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $domain = $stmt->fetchColumn();
            
            if (!$domain) {
                throw new Exception("Site not found");
            }
            
            // Create backup directory if it doesn't exist
            $siteBackupPath = $this->backupPath . '/' . $domain;
            if (!is_dir($siteBackupPath)) {
                mkdir($siteBackupPath, 0755, true);
            }
            
            // Create timestamp
            $timestamp = date('Y-m-d_H-i-s');
            $backupName = $domain . '_' . $timestamp;
            
            // 1. Backup database content
            $this->backupDatabase($siteId, $siteBackupPath, $backupName);
            
            // 2. Backup files
            $this->backupFiles($domain, $siteBackupPath, $backupName);
            
            // Log successful backup
            $this->logger->log($siteId, 'backup_created', "Backup '{$backupName}' created", 'success');
            
            return [
                'name' => $backupName,
                'path' => $siteBackupPath . '/' . $backupName . '.zip',
                'timestamp' => $timestamp
            ];
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'backup_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Restore backup
     */
    public function restoreBackup($siteId, $backupName) {
        try {
            // Get site info
            $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $domain = $stmt->fetchColumn();
            
            if (!$domain) {
                throw new Exception("Site not found");
            }
            
            $backupPath = $this->backupPath . '/' . $domain . '/' . $backupName;
            
            // Check if backup exists
            if (!file_exists($backupPath . '.zip')) {
                throw new Exception("Backup not found");
            }
            
            // Extract backup
            $zip = new ZipArchive();
            if ($zip->open($backupPath . '.zip') !== true) {
                throw new Exception("Failed to open backup archive");
            }
            
            $tempDir = $this->backupPath . '/temp_' . uniqid();
            mkdir($tempDir, 0755, true);
            $zip->extractTo($tempDir);
            $zip->close();
            
            // 1. Restore database content
            $this->restoreDatabase($siteId, $tempDir);
            
            // 2. Restore files
            $this->restoreFiles($domain, $tempDir);
            
            // Cleanup
            $this->removeDirectory($tempDir);
            
            $this->logger->log($siteId, 'backup_restored', "Backup '{$backupName}' restored", 'success');
            
            return true;
            
        } catch (Exception $e) {
            // Cleanup in case of error
            if (isset($tempDir) && is_dir($tempDir)) {
                $this->removeDirectory($tempDir);
            }
            
            $this->logger->log($siteId, 'restore_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Get available backups
     */
    public function getBackups($siteId) {
        // Get site domain
        $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
        $stmt->execute([$siteId]);
        $domain = $stmt->fetchColumn();
        
        if (!$domain) {
            return [];
        }
        
        $backupDir = $this->backupPath . '/' . $domain;
        if (!is_dir($backupDir)) {
            return [];
        }
        
        $backups = [];
        $files = glob($backupDir . '/*.zip');
        
        foreach ($files as $file) {
            $filename = basename($file, '.zip');
            $parts = explode('_', $filename);
            
            // Extract timestamp from filename
            array_shift($parts); // Remove domain
            $timestamp = implode('_', $parts);
            $dateTime = DateTime::createFromFormat('Y-m-d_H-i-s', $timestamp);
            
            if ($dateTime) {
                $backups[] = [
                    'name' => $filename,
                    'size' => filesize($file),
                    'created_at' => $dateTime->format('Y-m-d H:i:s'),
                    'file' => $file
                ];
            }
        }
        
        // Sort by creation date (newest first)
        usort($backups, function($a, $b) {
            return strtotime($b['created_at']) - strtotime($a['created_at']);
        });
        
        return $backups;
    }
    
    /**
     * Delete backup
     */
    public function deleteBackup($siteId, $backupName) {
        try {
            // Get site info
            $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $domain = $stmt->fetchColumn();
            
            if (!$domain) {
                throw new Exception("Site not found");
            }
            
            $backupFile = $this->backupPath . '/' . $domain . '/' . $backupName . '.zip';
            
            // Check if backup exists
            if (!file_exists($backupFile)) {
                throw new Exception("Backup not found");
            }
            
            // Delete backup file
            if (!unlink($backupFile)) {
                throw new Exception("Failed to delete backup file");
            }
            
            $this->logger->log($siteId, 'backup_deleted', "Backup '{$backupName}' deleted", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'backup_deletion_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Backup database content for a site
     */
    private function backupDatabase($siteId, $backupDir, $backupName) {
        $tables = [
            'pages' => "site_id = {$siteId}",
            'components' => "site_id = {$siteId}",
            'site_settings' => "site_id = {$siteId}",
            'redirects' => "site_id = {$siteId}",
            'media' => "site_id = {$siteId}",
            'sites' => "id = {$siteId}"
        ];
        
        $data = [];
        
        foreach ($tables as $table => $condition) {
            $stmt = $this->db->prepare("SELECT * FROM {$table} WHERE {$condition}");
            $stmt->execute();
            $data[$table] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }
        
        $dbBackupFile = $backupDir . '/' . $backupName . '_db.json';
        file_put_contents($dbBackupFile, json_encode($data, JSON_PRETTY_PRINT));
        
        return $dbBackupFile;
    }
    
    /**
     * Backup site files
     */
    private function backupFiles($domain, $backupDir, $backupName) {
        $sitePath = SITES_BASE_PATH . '/' . $domain;
        $filesBackupPath = $backupDir . '/' . $backupName . '_files';
        
        // Copy site files to backup directory
        $this->copyDirectory($sitePath, $filesBackupPath);
        
        // Create zip archive
        $zip = new ZipArchive();
        $zipFile = $backupDir . '/' . $backupName . '.zip';
        
        if ($zip->open($zipFile, ZipArchive::CREATE) !== true) {
            throw new Exception("Failed to create backup archive");
        }
        
        // Add database backup
        $dbBackupFile = $backupDir . '/' . $backupName . '_db.json';
        $zip->addFile($dbBackupFile, 'database.json');
        
        // Add site files
        $this->addDirectoryToZip($zip, $filesBackupPath, '');
        
        $zip->close();
        
        // Cleanup temporary files
        unlink($dbBackupFile);
        $this->removeDirectory($filesBackupPath);
        
        return $zipFile;
    }
    
    /**
     * Restore database from backup
     */
    private function restoreDatabase($siteId, $backupDir) {
        $dbFile = $backupDir . '/database.json';
        
        if (!file_exists($dbFile)) {
            throw new Exception("Database backup not found");
        }
        
        $data = json_decode(file_get_contents($dbFile), true);
        
        if (!$data) {
            throw new Exception("Invalid database backup format");
        }
        
        $this->db->beginTransaction();
        
        try {
            // Delete existing data
            $tables = ['pages', 'components', 'site_settings', 'redirects', 'media'];
            foreach ($tables as $table) {
                $stmt = $this->db->prepare("DELETE FROM {$table} WHERE site_id = ?");
                $stmt->execute([$siteId]);
            }
            
            // Restore data
            foreach ($data as $table => $rows) {
                if ($table === 'sites') {
                    // Only update specific fields for sites table
                    $siteData = $rows[0];
                    $stmt = $this->db->prepare("
                        UPDATE sites 
                        SET title = ?, active = ?, ssl_enabled = ?, cloudflare_enabled = ?
                        WHERE id = ?
                    ");
                    $stmt->execute([
                        $siteData['title'],
                        $siteData['active'],
                        $siteData['ssl_enabled'],
                        $siteData['cloudflare_enabled'],
                        $siteId
                    ]);
                } else {
                    // For other tables, restore all rows
                    foreach ($rows as $row) {
                        $fields = array_keys($row);
                        $values = array_values($row);
                        $placeholders = implode(', ', array_fill(0, count($fields), '?'));
                        
                        $sql = "INSERT INTO {$table} (" . implode(', ', $fields) . ") VALUES ({$placeholders})";
                        $stmt = $this->db->prepare($sql);
                        $stmt->execute($values);
                    }
                }
            }
            
            $this->db->commit();
            
        } catch (Exception $e) {
            $this->db->rollBack();
            throw new Exception("Failed to restore database: " . $e->getMessage());
        }
        
        return true;
    }
    
    /**
     * Restore site files
     */
    private function restoreFiles($domain, $backupDir) {
        $sitePath = SITES_BASE_PATH . '/' . $domain;
        $filesDir = $backupDir . '/files';
        
        if (!is_dir($filesDir)) {
            throw new Exception("Files backup not found");
        }
        
        // Backup current files before replacing
        $tempBackup = $sitePath . '_before_restore_' . uniqid();
        rename($sitePath, $tempBackup);
        
        try {
            // Create clean site directory
            mkdir($sitePath, 0755, true);
            
            // Copy files from backup
            $this->copyDirectory($filesDir, $sitePath);
            
            // Remove temporary backup
            $this->removeDirectory($tempBackup);
            
        } catch (Exception $e) {
            // Restore original files in case of error
            $this->removeDirectory($sitePath);
            rename($tempBackup, $sitePath);
            throw $e;
        }
        
        return true;
    }
    
    /**
     * Add directory to zip
     */
    private function addDirectoryToZip($zip, $dir, $relativePath) {
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($dir),
            RecursiveIteratorIterator::LEAVES_ONLY
        );
        
        foreach ($files as $file) {
            if (!$file->isDir()) {
                $filePath = $file->getRealPath();
                $zipPath = $relativePath . '/' . substr($filePath, strlen($dir) + 1);
                
                $zip->addFile($filePath, 'files' . $zipPath);
            }
        }
    }
    
    /**
     * Copy directory recursively
     */
    private function copyDirectory($source, $destination) {
        if (!is_dir($destination)) {
            mkdir($destination, 0755, true);
        }
        
        $iterator = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($source, RecursiveDirectoryIterator::SKIP_DOTS),
            RecursiveIteratorIterator::SELF_FIRST
        );
        
        foreach ($iterator as $item) {
            $target = $destination . '/' . $iterator->getSubPathName();
            
            if ($item->isDir()) {
                if (!is_dir($target)) {
                    mkdir($target, 0755, true);
                }
            } else {
                copy($item, $target);
            }
        }
    }
    
    /**
     * Remove directory recursively
     */
    private function removeDirectory($dir) {
        if (!is_dir($dir)) {
            return;
        }
        
        $objects = scandir($dir);
        foreach ($objects as $object) {
            if ($object !== '.' && $object !== '..') {
                $path = $dir . '/' . $object;
                
                if (is_dir($path)) {
                    $this->removeDirectory($path);
                } else {
                    unlink($path);
                }
            }
        }
        
        rmdir($dir);
    }
}