<?php
// includes/CloudflareManager.php

/**
 * Класс для управления API Cloudflare
 */
class CloudflareManager {
    private $apiKey;
    private $email;
    private $accountId;
    private $baseUrl = 'https://api.cloudflare.com/client/v4/';
    private $logger;
    
    /**
     * Конструктор
     */
    public function __construct() {
        $this->apiKey = CLOUDFLARE_API_TOKEN;
        $this->email = CLOUDFLARE_API_EMAIL;
        $this->logger = new SystemLogger(get_db_connection());
    }
    
    /**
     * Добавляет сайт в Cloudflare
     * 
     * @param string $domain Доменное имя
     * @return bool Результат операции
     */
    public function addSite($domain) {
        // Проверяем, настроен ли API ключ
        if (empty($this->apiKey) || $this->apiKey === 'your_cloudflare_api_token') {
            $this->logger->log(0, 'cloudflare', "Cloudflare API not configured. Skipping domain: $domain", 'warning');
            return false;
        }
        
        try {
            // Проверяем, может ли домен быть добавлен в Cloudflare
            if ($this->isDomainAddable($domain)) {
                // Создаем новую зону (сайт) в Cloudflare
                $response = $this->createZone($domain);
                
                if ($response && isset($response['success']) && $response['success'] === true) {
                    $this->logger->log(0, 'cloudflare', "Domain $domain added to Cloudflare successfully", 'success');
                    return true;
                } else {
                    $errorMsg = isset($response['errors'][0]['message']) ? $response['errors'][0]['message'] : 'Unknown error';
                    $this->logger->log(0, 'cloudflare', "Failed to add domain to Cloudflare: $errorMsg", 'error');
                    return false;
                }
            } else {
                $this->logger->log(0, 'cloudflare', "Domain $domain is not eligible for Cloudflare", 'warning');
                return false;
            }
        } catch (Exception $e) {
            $this->logger->log(0, 'cloudflare', "Cloudflare error: " . $e->getMessage(), 'error');
            return false;
        }
    }
    
    /**
     * Проверяет, можно ли добавить домен в Cloudflare
     * 
     * @param string $domain Доменное имя
     * @return bool Результат проверки
     */
    private function isDomainAddable($domain) {
        // Проверка, что домен соответствует требованиям Cloudflare
        if (!preg_match('/^([a-zA-Z0-9]([a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z]{2,}$/', $domain)) {
            return false;
        }
        
        // Проверяем, не добавлен ли уже этот домен
        $zones = $this->listZones();
        if ($zones && isset($zones['result'])) {
            foreach ($zones['result'] as $zone) {
                if ($zone['name'] === $domain) {
                    $this->logger->log(0, 'cloudflare', "Domain $domain already exists in Cloudflare", 'info');
                    return false;
                }
            }
        }
        
        return true;
    }
    
    /**
     * Получает список зон (сайтов) из Cloudflare
     * 
     * @return array|null Список зон или null в случае ошибки
     */
    public function listZones() {
        return $this->makeRequest('zones', 'GET');
    }
    
    /**
     * Создает новую зону (сайт) в Cloudflare
     * 
     * @param string $domain Доменное имя
     * @return array|null Результат операции или null в случае ошибки
     */
    private function createZone($domain) {
        $data = [
            'name' => $domain,
            'type' => 'full',
            'jump_start' => true
        ];
        
        return $this->makeRequest('zones', 'POST', $data);
    }
    
    /**
     * Выполняет запрос к API Cloudflare
     * 
     * @param string $endpoint Конечная точка API
     * @param string $method HTTP метод (GET, POST, PUT, DELETE)
     * @param array $data Данные для отправки (для POST, PUT)
     * @return array|null Результат запроса или null в случае ошибки
     */
    private function makeRequest($endpoint, $method = 'GET', $data = null) {
        $url = $this->baseUrl . $endpoint;
        
        $headers = [
            'X-Auth-Email: ' . $this->email,
            'X-Auth-Key: ' . $this->apiKey,
            'Content-Type: application/json'
        ];
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        
        if ($method === 'POST') {
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        } elseif ($method === 'PUT') {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PUT');
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        } elseif ($method === 'DELETE') {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');
        }
        
        $response = curl_exec($ch);
        
        if (curl_errno($ch)) {
            $this->logger->log(0, 'cloudflare', "Curl error: " . curl_error($ch), 'error');
            curl_close($ch);
            return null;
        }
        
        curl_close($ch);
        
        return json_decode($response, true);
    }
    
    /**
     * Удаляет сайт из Cloudflare
     * 
     * @param string $domain Доменное имя
     * @return bool Результат операции
     */
    public function removeSite($domain) {
        try {
            // Находим ID зоны для домена
            $zones = $this->listZones();
            $zoneId = null;
            
            if ($zones && isset($zones['result'])) {
                foreach ($zones['result'] as $zone) {
                    if ($zone['name'] === $domain) {
                        $zoneId = $zone['id'];
                        break;
                    }
                }
            }
            
            if ($zoneId) {
                // Удаляем зону по ID
                $response = $this->makeRequest('zones/' . $zoneId, 'DELETE');
                
                if ($response && isset($response['success']) && $response['success'] === true) {
                    $this->logger->log(0, 'cloudflare', "Domain $domain removed from Cloudflare successfully", 'success');
                    return true;
                } else {
                    $errorMsg = isset($response['errors'][0]['message']) ? $response['errors'][0]['message'] : 'Unknown error';
                    $this->logger->log(0, 'cloudflare', "Failed to remove domain from Cloudflare: $errorMsg", 'error');
                    return false;
                }
            } else {
                $this->logger->log(0, 'cloudflare', "Domain $domain not found in Cloudflare", 'warning');
                return false;
            }
        } catch (Exception $e) {
            $this->logger->log(0, 'cloudflare', "Cloudflare error: " . $e->getMessage(), 'error');
            return false;
        }
    }
    
    /**
     * Очищает кеш для домена в Cloudflare
     * 
     * @param string $domain Доменное имя
     * @return bool Результат операции
     */
    public function purgeCache($domain) {
        try {
            // Находим ID зоны для домена
            $zones = $this->listZones();
            $zoneId = null;
            
            if ($zones && isset($zones['result'])) {
                foreach ($zones['result'] as $zone) {
                    if ($zone['name'] === $domain) {
                        $zoneId = $zone['id'];
                        break;
                    }
                }
            }
            
            if ($zoneId) {
                // Очищаем весь кеш для зоны
                $data = ['purge_everything' => true];
                $response = $this->makeRequest('zones/' . $zoneId . '/purge_cache', 'POST', $data);
                
                if ($response && isset($response['success']) && $response['success'] === true) {
                    $this->logger->log(0, 'cloudflare', "Cache purged for domain $domain", 'success');
                    return true;
                } else {
                    $errorMsg = isset($response['errors'][0]['message']) ? $response['errors'][0]['message'] : 'Unknown error';
                    $this->logger->log(0, 'cloudflare', "Failed to purge cache: $errorMsg", 'error');
                    return false;
                }
            } else {
                $this->logger->log(0, 'cloudflare', "Domain $domain not found in Cloudflare", 'warning');
                return false;
            }
        } catch (Exception $e) {
            $this->logger->log(0, 'cloudflare', "Cloudflare error: " . $e->getMessage(), 'error');
            return false;
        }
    }
}