<?php
// includes/ContentManager.php
class ContentManager {
    private $db;
    private $logger;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        
        // Инициализируем логгер, если существует класс SystemLogger
        if (file_exists(__DIR__ . '/SystemLogger.php')) {
            require_once __DIR__ . '/SystemLogger.php';
            $this->logger = new SystemLogger($db);
        }
    }
    
    // -------------- PAGES MANAGEMENT --------------
    
    /**
     * Create a new page
     */
    public function createPage($siteId, $data) {
        try {
            $this->db->beginTransaction();
            
            // Validate slug
            $slug = !empty($data['slug']) ? $this->sanitizeSlug($data['slug']) : $this->generateSlug($data['title']);
            
            // Check if slug exists
            $stmt = $this->db->prepare("SELECT id FROM pages WHERE site_id = ? AND slug = ?");
            $stmt->execute([$siteId, $slug]);
            if ($stmt->fetchColumn()) {
                throw new Exception("Page with this slug already exists");
            }
            
            // Формируем набор полей для вставки
            $fields = [
                'site_id' => $siteId,
                'title' => $data['title'],
                'slug' => $slug,
                'content' => $data['content'] ?? '',
                'h1' => $data['h1'] ?? $data['title'],
                'meta_title' => $data['meta_title'] ?? $data['title'],
                'meta_description' => $data['meta_description'] ?? '',
                'is_published' => $data['is_published'] ?? 1,
                'is_system' => $data['is_system'] ?? 0,
                'created_at' => date('Y-m-d H:i:s'),
                'updated_at' => date('Y-m-d H:i:s')
            ];
            
            // Формируем SQL запрос
            $columns = implode(', ', array_keys($fields));
            $placeholders = implode(', ', array_fill(0, count($fields), '?'));
            
            $stmt = $this->db->prepare("INSERT INTO pages ($columns) VALUES ($placeholders)");
            $stmt->execute(array_values($fields));
            
            $pageId = $this->db->lastInsertId();
            
            $this->logger->log($siteId, 'page_created', "Page '{$data['title']}' created with ID {$pageId}", 'success');
            
            $this->db->commit();
            return $pageId;
            
        } catch (Exception $e) {
            $this->db->rollBack();
            $this->logger->log($siteId, 'page_creation_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Update an existing page
     */
    public function updatePage($pageId, $data) {
        try {
            $this->db->beginTransaction();
            
            // Get page info
            $currentPage = $this->getPage($pageId);
            
            if (!$currentPage) {
                throw new Exception("Page not found");
            }
            
            // Validate slug if changed
            $slug = !empty($data['slug']) ? $this->sanitizeSlug($data['slug']) : $this->generateSlug($data['title']);
            
            if ($slug !== $currentPage['slug']) {
                // Check if new slug exists
                $stmt = $this->db->prepare("
                    SELECT id FROM pages 
                    WHERE site_id = ? AND slug = ? AND id != ?
                ");
                $stmt->execute([$currentPage['site_id'], $slug, $pageId]);
                if ($stmt->fetchColumn()) {
                    throw new Exception("Page with this slug already exists");
                }
            }
            
            // Формируем данные для обновления
            $fields = [
                'title' => $data['title'],
                'slug' => $slug,
                'content' => $data['content'] ?? $currentPage['content'],
                'h1' => $data['h1'] ?? $data['title'],
                'meta_title' => $data['meta_title'] ?? $data['title'],
                'meta_description' => $data['meta_description'] ?? $currentPage['meta_description'],
                'is_published' => isset($data['is_published']) ? $data['is_published'] : $currentPage['is_published'],
                'is_system' => isset($data['is_system']) ? $data['is_system'] : $currentPage['is_system'],
                'updated_at' => date('Y-m-d H:i:s')
            ];
            
            // Формируем SQL запрос
            $updates = [];
            foreach ($fields as $field => $value) {
                $updates[] = "$field = ?";
            }
            $updateStr = implode(', ', $updates);
            
            // Добавляем ID в конец списка параметров
            $params = array_values($fields);
            $params[] = $pageId;
            
            $stmt = $this->db->prepare("UPDATE pages SET $updateStr WHERE id = ?");
            $stmt->execute($params);
            
            $this->logger->log($currentPage['site_id'], 'page_updated', "Page '{$fields['title']}' updated", 'success');
            
            $this->db->commit();
            return true;
            
        } catch (Exception $e) {
            if ($this->db->inTransaction()) {
                $this->db->rollBack();
            }
            $this->logger->log($currentPage['site_id'] ?? 0, 'page_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Delete a page
     */
    public function deletePage($pageId) {
        try {
            // Get page info
            $page = $this->getPage($pageId);
            
            if (!$page) {
                throw new Exception("Page not found");
            }
            
            // Prevent deletion of system pages
            if ($page['is_system']) {
                throw new Exception("Cannot delete system page");
            }
            
            // Delete page
            $stmt = $this->db->prepare("DELETE FROM pages WHERE id = ?");
            $stmt->execute([$pageId]);
            
            $this->logger->log($page['site_id'], 'page_deleted', "Page '{$page['title']}' deleted", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($page['site_id'] ?? 0, 'page_deletion_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Get page by ID
     */
    public function getPage($pageId) {
        $stmt = $this->db->prepare("SELECT * FROM pages WHERE id = ?");
        $stmt->execute([$pageId]);
        $page = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($page) {
            // Установка значений по умолчанию для отсутствующих полей
            $page['is_published'] = $page['is_published'] ?? 1;
            $page['is_system'] = $page['is_system'] ?? 0;
            $page['meta_description'] = $page['meta_description'] ?? '';
        }
        
        return $page;
    }
    
    /**
     * Get pages by site ID
     */
    public function getPages($siteId, $options = []) {
        $sql = "SELECT * FROM pages WHERE site_id = ?";
        $params = [$siteId];
        
        // Add filters
        if (isset($options['exclude_system']) && $options['exclude_system']) {
            $sql .= " AND is_system = 0";
        }
        
        if (isset($options['is_published']) && $options['is_published'] !== null) {
            $sql .= " AND is_published = ?";
            $params[] = $options['is_published'];
        }
        
        if (isset($options['is_system']) && $options['is_system'] !== null) {
            $sql .= " AND is_system = ?";
            $params[] = $options['is_system'];
        }
        
        if (!empty($options['search'])) {
            $sql .= " AND (title LIKE ? OR slug LIKE ? OR content LIKE ?)";
            $searchTerm = '%' . $options['search'] . '%';
            $params[] = $searchTerm;
            $params[] = $searchTerm;
            $params[] = $searchTerm;
        }
        
        // Add ordering
        $sql .= " ORDER BY " . ($options['order_by'] ?? "is_system DESC, title ASC");
        
        // Add limit
        if (isset($options['limit'])) {
            $sql .= " LIMIT " . (int)$options['limit'];
            if (isset($options['offset'])) {
                $sql .= " OFFSET " . (int)$options['offset'];
            }
        }
        
        $stmt = $this->db->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Get page by slug
     */
    public function getPageBySlug($siteId, $slug) {
        $stmt = $this->db->prepare("SELECT * FROM pages WHERE site_id = ? AND slug = ?");
        $stmt->execute([$siteId, $slug]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    
    // -------------- COMPONENTS MANAGEMENT --------------
    
    /**
     * Create a new component
     */
    public function createComponent($siteId, $data) {
        try {
            $stmt = $this->db->prepare("
                INSERT INTO components (
                    site_id, name, type, content, is_active
                ) VALUES (?, ?, ?, ?, ?)
            ");
            
            $stmt->execute([
                $siteId,
                $data['name'],
                $data['type'],
                $data['content'],
                $data['is_active'] ?? true
            ]);
            
            $componentId = $this->db->lastInsertId();
            $this->logger->log($siteId, 'component_created', "Component '{$data['name']}' created", 'success');
            
            return $componentId;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'component_creation_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Update a component
     */
    public function updateComponent($componentId, $data) {
        try {
            // Get component info
            $stmt = $this->db->prepare("SELECT site_id FROM components WHERE id = ?");
            $stmt->execute([$componentId]);
            $component = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$component) {
                throw new Exception("Component not found");
            }
            
            // Update component
            $stmt = $this->db->prepare("
                UPDATE components SET
                    name = ?,
                    content = ?,
                    is_active = ?,
                    updated_at = CURRENT_TIMESTAMP
                WHERE id = ?
            ");
            
            $stmt->execute([
                $data['name'],
                $data['content'],
                $data['is_active'] ?? true,
                $componentId
            ]);
            
            $this->logger->log($component['site_id'], 'component_updated', "Component '{$data['name']}' updated", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($component['site_id'] ?? 0, 'component_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Get active components by site and type
     */
    public function getComponents($siteId, $type = null) {
        $sql = "SELECT * FROM components WHERE site_id = ? AND is_active = 1";
        $params = [$siteId];
        
        if ($type) {
            $sql .= " AND type = ?";
            $params[] = $type;
        }
        
        $sql .= " ORDER BY type, name";
        
        $stmt = $this->db->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    // -------------- MENU MANAGEMENT --------------
    
    /**
     * Generate navigation menu
     */
    public function generateMenu($siteId, $currentSlug = '') {
        // Get all non-system pages
        $pages = $this->getPages($siteId, ['exclude_system' => true]);
        
        $menuHtml = "<ul class=\"nav-menu\">\n";
        foreach ($pages as $page) {
            $isActive = ($page['slug'] === $currentSlug) ? ' class="active"' : '';
            $menuHtml .= "    <li{$isActive}><a href=\"/{$page['slug']}\">{$page['title']}</a></li>\n";
        }
        $menuHtml .= "</ul>";
        
        return $menuHtml;
    }
    
    // -------------- HELPER METHODS --------------
    
    /**
     * Генерирует slug из заголовка
     * 
     * @param string $title Заголовок
     * @return string Сгенерированный slug
     */
    public function generateSlug($title) {
        // Транслитерация для русских букв (если нужно)
        $transliterationMap = [
            'а' => 'a', 'б' => 'b', 'в' => 'v', 'г' => 'g', 'д' => 'd', 'е' => 'e',
            'ё' => 'e', 'ж' => 'zh', 'з' => 'z', 'и' => 'i', 'й' => 'y', 'к' => 'k',
            'л' => 'l', 'м' => 'm', 'н' => 'n', 'о' => 'o', 'п' => 'p', 'р' => 'r',
            'с' => 's', 'т' => 't', 'у' => 'u', 'ф' => 'f', 'х' => 'h', 'ц' => 'c',
            'ч' => 'ch', 'ш' => 'sh', 'щ' => 'sch', 'ъ' => '', 'ы' => 'y', 'ь' => '',
            'э' => 'e', 'ю' => 'yu', 'я' => 'ya',
            'А' => 'A', 'Б' => 'B', 'В' => 'V', 'Г' => 'G', 'Д' => 'D', 'Е' => 'E',
            'Ё' => 'E', 'Ж' => 'Zh', 'З' => 'Z', 'И' => 'I', 'Й' => 'Y', 'К' => 'K',
            'Л' => 'L', 'М' => 'M', 'Н' => 'N', 'О' => 'O', 'П' => 'P', 'Р' => 'R',
            'С' => 'S', 'Т' => 'T', 'У' => 'U', 'Ф' => 'F', 'Х' => 'H', 'Ц' => 'C',
            'Ч' => 'Ch', 'Ш' => 'Sh', 'Щ' => 'Sch', 'Ъ' => '', 'Ы' => 'Y', 'Ь' => '',
            'Э' => 'E', 'Ю' => 'Yu', 'Я' => 'Ya'
        ];
        
        // Сначала применяем транслитерацию
        $title = strtr($title, $transliterationMap);
        
        // Конвертируем в нижний регистр
        $slug = strtolower($title);
        
        // Удаляем все символы, кроме букв, цифр и пробелов
        $slug = preg_replace('/[^a-z0-9\s]/', '', $slug);
        
        // Заменяем пробелы на дефисы
        $slug = preg_replace('/\s+/', '-', $slug);
        
        // Удаляем повторяющиеся дефисы
        $slug = preg_replace('/-+/', '-', $slug);
        
        // Обрезаем лишние дефисы в начале и конце
        $slug = trim($slug, '-');
        
        return $slug ?: 'page';
    }
    
    /**
     * Sanitize slug
     */
    private function sanitizeSlug($slug) {
        // Remove accents
        $slug = iconv('UTF-8', 'ASCII//TRANSLIT', $slug);
        // Convert to lowercase
        $slug = strtolower($slug);
        // Replace non-alphanumeric characters with hyphens
        $slug = preg_replace('/[^a-z0-9-]/', '-', $slug);
        // Replace multiple hyphens with single hyphen
        $slug = preg_replace('/-+/', '-', $slug);
        // Trim hyphens from beginning and end
        $slug = trim($slug, '-');
        
        return $slug ?: 'page';
    }
    
    /**
     * Проверяет уникальность slug
     * 
     * @param int $siteId ID сайта
     * @param string $slug Slug для проверки
     * @param int|null $excludePageId ID страницы для исключения из проверки (при обновлении)
     * @throws Exception Если slug не уникален
     */
    private function validateSlug($siteId, $slug, $excludePageId = null) {
        $sql = "SELECT id FROM pages WHERE site_id = ? AND slug = ?";
        $params = [$siteId, $slug];
        
        if ($excludePageId) {
            $sql .= " AND id != ?";
            $params[] = $excludePageId;
        }
        
        $stmt = $this->db->prepare($sql);
        $stmt->execute($params);
        
        if ($stmt->fetch()) {
            throw new Exception("Page with slug '{$slug}' already exists");
        }
        
        return true;
    }
}