<?php
// includes/MediaManager.php
class MediaManager {
    private $db;
    private $logger;
    private $allowedTypes;
    private $mediaBasePath;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->logger = new SystemLogger($db);
        $this->allowedTypes = [
            'image/jpeg', 'image/png', 'image/gif', 'image/webp',
            'application/pdf', 'application/zip', 
            'text/plain', 'text/csv'
        ];
        $this->mediaBasePath = SITES_BASE_PATH;
    }
    
    /**
     * Upload file
     */
    public function uploadFile($siteId, $file, $directory = 'uploads') {
        try {
            // Validate file
            if (!isset($file['tmp_name']) || !is_uploaded_file($file['tmp_name'])) {
                throw new Exception("Invalid file upload");
            }
            
            // Check file type
            if (!in_array($file['type'], $this->allowedTypes)) {
                throw new Exception("File type not allowed");
            }
            
            // Get site info
            $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $domain = $stmt->fetchColumn();
            
            if (!$domain) {
                throw new Exception("Site not found");
            }
            
            // Create uploads directory if it doesn't exist
            $uploadPath = $this->mediaBasePath . '/' . $domain . '/' . $directory;
            if (!file_exists($uploadPath)) {
                if (!mkdir($uploadPath, 0755, true)) {
                    throw new Exception("Failed to create upload directory");
                }
            }
            
            // Generate safe filename
            $filename = $this->sanitizeFilename($file['name']);
            $extension = pathinfo($filename, PATHINFO_EXTENSION);
            $basename = pathinfo($filename, PATHINFO_FILENAME);
            $uniqueName = $basename . '_' . uniqid() . '.' . $extension;
            $destination = $uploadPath . '/' . $uniqueName;
            
            // Move file
            if (!move_uploaded_file($file['tmp_name'], $destination)) {
                throw new Exception("Failed to move uploaded file");
            }
            
            // Set proper permissions
            chmod($destination, 0644);
            
            // Save file info to database
            $stmt = $this->db->prepare("
                INSERT INTO media (
                    site_id, filename, original_name, file_path, file_type, file_size
                ) VALUES (?, ?, ?, ?, ?, ?)
            ");
            
            $stmt->execute([
                $siteId,
                $uniqueName,
                $file['name'],
                $directory . '/' . $uniqueName,
                $file['type'],
                $file['size']
            ]);
            
            $fileId = $this->db->lastInsertId();
            $this->logger->log($siteId, 'file_uploaded', "File '{$file['name']}' uploaded", 'success');
            
            // Return file info
            return [
                'id' => $fileId,
                'filename' => $uniqueName,
                'path' => $directory . '/' . $uniqueName,
                'url' => '/' . $directory . '/' . $uniqueName
            ];
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'file_upload_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Delete file
     */
    public function deleteFile($fileId) {
        try {
            // Get file info
            $stmt = $this->db->prepare("
                SELECT m.*, s.domain 
                FROM media m 
                JOIN sites s ON m.site_id = s.id 
                WHERE m.id = ?
            ");
            $stmt->execute([$fileId]);
            $file = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$file) {
                throw new Exception("File not found");
            }
            
            // Delete physical file
            $filePath = $this->mediaBasePath . '/' . $file['domain'] . '/' . $file['file_path'];
            if (file_exists($filePath)) {
                unlink($filePath);
            }
            
            // Delete database record
            $stmt = $this->db->prepare("DELETE FROM media WHERE id = ?");
            $stmt->execute([$fileId]);
            
            $this->logger->log($file['site_id'], 'file_deleted', "File '{$file['original_name']}' deleted", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($file['site_id'] ?? 0, 'file_deletion_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Get files by site ID
     */
    public function getFiles($siteId, $options = []) {
        $sql = "SELECT * FROM media WHERE site_id = ?";
        $params = [$siteId];
        
        // Add filters
        if (isset($options['type'])) {
            $sql .= " AND file_type LIKE ?";
            $params[] = $options['type'] . '%';
        }
        
        // Add ordering
        $sql .= " ORDER BY " . ($options['order_by'] ?? "created_at DESC");
        
        // Add limit
        if (isset($options['limit'])) {
            $sql .= " LIMIT " . (int)$options['limit'];
            if (isset($options['offset'])) {
                $sql .= " OFFSET " . (int)$options['offset'];
            }
        }
        
        $stmt = $this->db->prepare($sql);
        $stmt->execute($params);
        
        $files = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Get site domain for URL generation
        $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
        $stmt->execute([$siteId]);
        $domain = $stmt->fetchColumn();
        
        // Add URL to each file
        if ($domain) {
            foreach ($files as &$file) {
                $file['url'] = '/' . $file['file_path'];
            }
        }
        
        return $files;
    }
    
    /**
     * Sanitize filename
     */
    private function sanitizeFilename($filename) {
        // Remove accent characters
        $filename = iconv('UTF-8', 'ASCII//TRANSLIT', $filename);
        // Replace spaces
        $filename = str_replace(' ', '_', $filename);
        // Remove all characters except alphanumeric, dash, underscore and dot
        $filename = preg_replace('/[^A-Za-z0-9\-\_\.]/', '', $filename);
        // Make lowercase
        $filename = strtolower($filename);
        
        return $filename;
    }
}