<?php
// includes/RedirectManager.php
class RedirectManager {
    private $db;
    private $logger;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->logger = new SystemLogger($db);
    }
    
    /**
     * Add redirect
     */
    public function addRedirect($siteId, $sourceUrl, $targetUrl, $redirectType = '301') {
        try {
            // Validate URLs
            $sourceUrl = $this->normalizeUrl($sourceUrl);
            $targetUrl = $this->normalizeUrl($targetUrl);
            
            // Check if redirect already exists
            $stmt = $this->db->prepare("
                SELECT id FROM redirects 
                WHERE site_id = ? AND source_url = ?
            ");
            $stmt->execute([$siteId, $sourceUrl]);
            
            if ($stmt->fetch()) {
                // Update existing redirect
                $stmt = $this->db->prepare("
                    UPDATE redirects 
                    SET target_url = ?, redirect_type = ?, is_active = 1
                    WHERE site_id = ? AND source_url = ?
                ");
                $stmt->execute([$targetUrl, $redirectType, $siteId, $sourceUrl]);
            } else {
                // Create new redirect
                $stmt = $this->db->prepare("
                    INSERT INTO redirects (site_id, source_url, target_url, redirect_type)
                    VALUES (?, ?, ?, ?)
                ");
                $stmt->execute([$siteId, $sourceUrl, $targetUrl, $redirectType]);
            }
            
            $this->updateHtaccess($siteId);
            $this->logger->log($siteId, 'redirect_added', "Redirect from '{$sourceUrl}' to '{$targetUrl}' added", 'success');
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'redirect_add_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Update redirect
     */
    public function updateRedirect($redirectId, $targetUrl, $redirectType = '301', $isActive = true) {
        try {
            // Get redirect info
            $stmt = $this->db->prepare("SELECT site_id, source_url FROM redirects WHERE id = ?");
            $stmt->execute([$redirectId]);
            $redirect = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$redirect) {
                throw new Exception("Redirect not found");
            }
            
            $targetUrl = $this->normalizeUrl($targetUrl);
            
            // Update redirect
            $stmt = $this->db->prepare("
                UPDATE redirects 
                SET target_url = ?, redirect_type = ?, is_active = ?
                WHERE id = ?
            ");
            $stmt->execute([$targetUrl, $redirectType, $isActive ? 1 : 0, $redirectId]);
            
            $this->updateHtaccess($redirect['site_id']);
            $this->logger->log(
                $redirect['site_id'], 
                'redirect_updated', 
                "Redirect from '{$redirect['source_url']}' updated", 
                'success'
            );
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($redirect['site_id'] ?? 0, 'redirect_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Delete redirect
     */
    public function deleteRedirect($redirectId) {
        try {
            // Get redirect info
            $stmt = $this->db->prepare("SELECT site_id, source_url FROM redirects WHERE id = ?");
            $stmt->execute([$redirectId]);
            $redirect = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$redirect) {
                throw new Exception("Redirect not found");
            }
            
            // Delete redirect
            $stmt = $this->db->prepare("DELETE FROM redirects WHERE id = ?");
            $stmt->execute([$redirectId]);
            
            $this->updateHtaccess($redirect['site_id']);
            $this->logger->log(
                $redirect['site_id'], 
                'redirect_deleted', 
                "Redirect from '{$redirect['source_url']}' deleted", 
                'success'
            );
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($redirect['site_id'] ?? 0, 'redirect_deletion_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Get redirects by site ID
     */
    public function getRedirects($siteId, $onlyActive = true) {
        $sql = "SELECT * FROM redirects WHERE site_id = ?";
        $params = [$siteId];
        
        if ($onlyActive) {
            $sql .= " AND is_active = 1";
        }
        
        $sql .= " ORDER BY source_url";
        
        $stmt = $this->db->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    /**
     * Update .htaccess file with redirects
     */
    private function updateHtaccess($siteId) {
        try {
            // Get site domain
            $stmt = $this->db->prepare("SELECT domain FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $domain = $stmt->fetchColumn();
            
            if (!$domain) {
                throw new Exception("Site not found");
            }
            
            // Get active redirects
            $redirects = $this->getRedirects($siteId, true);
            
            // Generate redirects section for .htaccess
            $redirectsContent = "# Redirects - Auto-generated by PBN Admin\n";
            foreach ($redirects as $redirect) {
                $redirectsContent .= "RewriteRule ^" . ltrim($redirect['source_url'], '/') . "$ " . 
                                     $redirect['target_url'] . " [R=" . $redirect['redirect_type'] . ",L]\n";
            }
            
            // Path to .htaccess
            $htaccessPath = SITES_BASE_PATH . '/' . $domain . '/.htaccess';
            
            // Read current .htaccess
            if (file_exists($htaccessPath)) {
                $currentContent = file_get_contents($htaccessPath);
                
                // Remove existing redirects section
                $pattern = '/# Redirects - Auto-generated by PBN Admin\n(.*?)# End of redirects/s';
                $currentContent = preg_replace($pattern, '', $currentContent);
                
                // Add new redirects section after RewriteEngine On
                $redirectsContent .= "# End of redirects\n\n";
                $currentContent = preg_replace(
                    '/(RewriteEngine On\n)/', 
                    "$1\n" . $redirectsContent, 
                    $currentContent
                );
                
                // Write updated .htaccess
                file_put_contents($htaccessPath, $currentContent);
            }
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'htaccess_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Normalize URL
     */
    private function normalizeUrl($url) {
        // Ensure URL starts with /
        if (strpos($url, 'http') !== 0 && substr($url, 0, 1) !== '/') {
            $url = '/' . $url;
        }
        
        return $url;
    }
}