<?php
// includes/SettingsManager.php
class SettingsManager {
    private $db;
    private $logger;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->logger = new SystemLogger($db);
    }
    
    /**
     * Get site settings
     */
    public function getSettings($siteId) {
        $stmt = $this->db->prepare("SELECT key_name, value FROM site_settings WHERE site_id = ?");
        $stmt->execute([$siteId]);
        
        $settings = [];
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $settings[$row['key_name']] = $row['value'];
        }
        
        return $settings;
    }
    
    /**
     * Get single setting
     */
    public function getSetting($siteId, $key, $default = null) {
        $stmt = $this->db->prepare("SELECT value FROM site_settings WHERE site_id = ? AND key_name = ?");
        $stmt->execute([$siteId, $key]);
        
        $value = $stmt->fetchColumn();
        return $value !== false ? $value : $default;
    }
    
    /**
     * Update setting
     */
    public function updateSetting($siteId, $key, $value) {
        try {
            // Check if setting exists
            $stmt = $this->db->prepare("SELECT id FROM site_settings WHERE site_id = ? AND key_name = ?");
            $stmt->execute([$siteId, $key]);
            
            if ($stmt->fetch()) {
                // Update existing setting
                $stmt = $this->db->prepare("
                    UPDATE site_settings 
                    SET value = ?, updated_at = CURRENT_TIMESTAMP
                    WHERE site_id = ? AND key_name = ?
                ");
                $stmt->execute([$value, $siteId, $key]);
            } else {
                // Insert new setting
                $stmt = $this->db->prepare("
                    INSERT INTO site_settings (site_id, key_name, value)
                    VALUES (?, ?, ?)
                ");
                $stmt->execute([$siteId, $key, $value]);
            }
            
            $this->logger->log($siteId, 'setting_updated', "Setting '{$key}' updated", 'success');
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'setting_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Update multiple settings
     */
    public function updateSettings($siteId, $settings) {
        try {
            $this->db->beginTransaction();
            
            foreach ($settings as $key => $value) {
                $this->updateSetting($siteId, $key, $value);
            }
            
            $this->db->commit();
            return true;
            
        } catch (Exception $e) {
            $this->db->rollBack();
            $this->logger->log($siteId, 'settings_update_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Delete setting
     */
    public function deleteSetting($siteId, $key) {
        try {
            $stmt = $this->db->prepare("DELETE FROM site_settings WHERE site_id = ? AND key_name = ?");
            $stmt->execute([$siteId, $key]);
            
            $this->logger->log($siteId, 'setting_deleted', "Setting '{$key}' deleted", 'success');
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'setting_deletion_error', $e->getMessage(), 'error');
            throw $e;
        }
    }
}