<?php
// includes/SiteManager.php
class SiteManager {
    private $db;
    private $logger;
    private $apacheManager;
    private $cloudflareManager = null;
    private $config;
    
    /**
     * Конструктор класса SiteManager
     * 
     * @param PDO $db Объект подключения к базе данных
     */
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->logger = new SystemLogger($db);
        $this->apacheManager = new ApacheManager();
        
        // Проверяем существует ли класс CloudflareManager
        if (file_exists(__DIR__ . '/CloudflareManager.php')) {
            require_once __DIR__ . '/CloudflareManager.php';
            if (class_exists('CloudflareManager')) {
                $this->cloudflareManager = new CloudflareManager();
            }
        }
        
        // Загружаем конфигурацию
        $this->config = [
            'db' => [
                'host' => DB_HOST,
                'name' => DB_NAME,
                'user' => DB_USER,
                'pass' => DB_PASS
            ]
        ];
    }
    
    /**
     * Создает сайт
     * 
     * @param string $domain Доменное имя
     * @param string $title Заголовок сайта
     * @param bool $active Статус активности
     * @param bool $ssl_enabled Включен ли SSL
     * @param bool $cloudflare_enabled Включен ли Cloudflare
     * @return int|bool ID созданного сайта или false в случае ошибки
     */
    public function createSite($domain, $title, $active = true, $ssl_enabled = true, $cloudflare_enabled = false) {
        try {
            $this->db->beginTransaction();
            
            // 1. Создаем запись в БД
            $stmt = $this->db->prepare("INSERT INTO sites (domain, title, active, ssl_enabled, cloudflare_enabled) 
                                        VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([$domain, $title, $active ? 1 : 0, $ssl_enabled ? 1 : 0, $cloudflare_enabled ? 1 : 0]);
            $siteId = $this->db->lastInsertId();
            
            $this->logger->log($siteId, 'site_creation', "Site record created in database: $domain", 'success');
            
            // 2. Создаем директорию сайта
            $sitePath = SITES_BASE_PATH . '/' . $domain;
            if (!file_exists($sitePath)) {
                if (!mkdir($sitePath, 0755, true)) {
                    throw new Exception("Failed to create site directory: $sitePath");
                }
                $this->logger->log($siteId, 'site_creation', "Directory created: $sitePath", 'success');
            } else {
                $this->logger->log($siteId, 'site_creation', "Directory already exists: $sitePath", 'warning');
            }
            
            // 3. Создаем конфиг Apache
            try {
                $this->apacheManager->createConfig($domain, $sitePath);
                $this->logger->log($siteId, 'apache_setup', "Apache configuration created for $domain", 'success');
            } catch (Exception $e) {
                // Логируем ошибку, но продолжаем процесс
                $this->logger->log($siteId, 'apache_setup', "Apache configuration failed: " . $e->getMessage(), 'warning');
            }
            
            // 4. Настраиваем CloudFlare, если нужно и если менеджер доступен
            if ($cloudflare_enabled && $this->cloudflareManager !== null) {
                try {
                    if ($this->cloudflareManager->addSite($domain)) {
                        $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare configuration completed for $domain", 'success');
                    } else {
                        $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare configuration failed for $domain", 'warning');
                    }
                } catch (Exception $e) {
                    // Логируем ошибку, но продолжаем процесс
                    $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare error: " . $e->getMessage(), 'warning');
                }
            } elseif ($cloudflare_enabled) {
                $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare manager is not available", 'warning');
            }
            
            // 5. Устанавливаем базовые файлы сайта
            $this->setupSiteFiles($siteId, $sitePath);
            
            // 6. Создаем системные страницы, если нужно
            // Эта часть уже реализована в site-create.php, поэтому пропускаем
            
            $this->db->commit();
            
            $this->logger->log($siteId, 'site_creation', "Site $domain ($title) created successfully", 'success');
            return $siteId;
            
        } catch (Exception $e) {
            $this->db->rollBack();
            $this->logger->log(0, 'site_creation', "Failed to create site $domain: " . $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Устанавливает базовые файлы сайта
     * 
     * @param int $siteId ID сайта
     * @param string $sitePath Путь к директории сайта
     */
    private function setupSiteFiles($siteId, $sitePath) {
        // Копируем index.php
        if (file_exists(TEMPLATES_PATH . '/index.template.php')) {
            if (!copy(TEMPLATES_PATH . '/index.template.php', $sitePath . '/index.php')) {
                throw new Exception("Failed to copy index template");
            }
            $this->logger->log($siteId, 'site_creation', "Index file created", 'success');
        } else {
            // Если шаблон не найден, создаем базовый index.php
            $indexContent = $this->generateIndexPhp($siteId);
            if (!file_put_contents($sitePath . '/index.php', $indexContent)) {
                throw new Exception("Failed to create index.php file");
            }
            $this->logger->log($siteId, 'site_creation', "Basic index.php created", 'success');
        }
        
        // Создаем .htaccess
        $htaccessContent = $this->generateHtaccess();
        if (!file_put_contents($sitePath . '/.htaccess', $htaccessContent)) {
            throw new Exception("Failed to create .htaccess file");
        }
        $this->logger->log($siteId, 'site_creation', "Htaccess file created", 'success');
        
        // Создаем локальный конфиг
        $configContent = $this->generateConfig($siteId);
        if (!file_put_contents($sitePath . '/config.php', $configContent)) {
            throw new Exception("Failed to create config.php file");
        }
        $this->logger->log($siteId, 'site_creation', "Config file created", 'success');
    }
    
    /**
     * Генерирует содержимое .htaccess файла
     * 
     * @return string Содержимое файла
     */
    private function generateHtaccess() {
        return <<<HTACCESS
RewriteEngine On
RewriteBase /
# Если файл или директория существуют, используем их напрямую
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
# Иначе перенаправляем все запросы на index.php
RewriteRule ^(.*)$ index.php [L,QSA]
# Базовые настройки безопасности
Options -Indexes +FollowSymLinks
ServerSignature Off
# Защита системных файлов
<FilesMatch "^\.">
    Order allow,deny
    Deny from all
</FilesMatch>
HTACCESS;
    }
    
    /**
     * Генерирует содержимое файла config.php для сайта
     * 
     * @param int $siteId ID сайта
     * @return string Содержимое файла
     */
    private function generateConfig($siteId) {
        return <<<PHP
<?php
define('SITE_ID', $siteId);
define('DB_HOST', '{$this->config['db']['host']}');
define('DB_NAME', '{$this->config['db']['name']}');
define('DB_USER', '{$this->config['db']['user']}');
define('DB_PASS', '{$this->config['db']['pass']}');
function getDB() {
    try {
        \$db = new PDO(
            "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
            DB_USER,
            DB_PASS,
            array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
        );
        return \$db;
    } catch(PDOException \$e) {
        die("Connection failed: " . \$e->getMessage());
    }
}
PHP;
    }
    
    /**
     * Генерирует базовый index.php, если шаблон недоступен
     * 
     * @param int $siteId ID сайта
     * @return string Содержимое файла
     */
    private function generateIndexPhp($siteId) {
        return <<<PHP
<?php
// Подключаем конфигурацию
require_once __DIR__ . '/config.php';

// Получаем данные сайта
\$db = getDB();
\$stmt = \$db->prepare("SELECT * FROM sites WHERE id = ?");
\$stmt->execute([\$siteId]);
\$site = \$stmt->fetch(PDO::FETCH_ASSOC);

if (!\$site) {
    die("Site not found");
}

// Получаем текущий URL
\$requestUri = \$_SERVER['REQUEST_URI'];
\$baseUrl = '/';
\$path = trim(parse_url(\$requestUri, PHP_URL_PATH), '/');

// Определяем, какую страницу показывать
\$slug = empty(\$path) ? 'home' : \$path;

// Получаем страницу из базы данных
\$stmt = \$db->prepare("SELECT * FROM pages WHERE site_id = ? AND slug = ?");
\$stmt->execute([\$siteId, \$slug]);
\$page = \$stmt->fetch(PDO::FETCH_ASSOC);

// Если страница не найдена, показываем 404
if (!\$page) {
    \$stmt = \$db->prepare("SELECT * FROM pages WHERE site_id = ? AND slug = '404'");
    \$stmt->execute([\$siteId]);
    \$page = \$stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!\$page) {
        // Если нет даже 404 страницы, показываем стандартную ошибку
        header("HTTP/1.0 404 Not Found");
        echo "<h1>404 - Page Not Found</h1>";
        exit;
    }
    
    header("HTTP/1.0 404 Not Found");
}

// Получаем компоненты сайта (header, footer)
\$components = [];
\$stmt = \$db->prepare("SELECT * FROM components WHERE site_id = ? AND is_active = 1");
\$stmt->execute([\$siteId]);
while (\$component = \$stmt->fetch(PDO::FETCH_ASSOC)) {
    \$components[\$component['type']] = \$component['content'];
}

// Выводим HTML страницы
?><!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars(\$page['meta_title'] ?: \$page['title']); ?></title>
    <meta name="description" content="<?php echo htmlspecialchars(\$page['meta_description'] ?? ''); ?>">
</head>
<body>
    <?php 
    // Выводим header, если есть
    if (isset(\$components['header'])) {
        echo \$components['header'];
    }
    
    // Выводим содержимое страницы
    echo \$page['content'];
    
    // Выводим footer, если есть
    if (isset(\$components['footer'])) {
        echo \$components['footer'];
    }
    ?>
</body>
</html>
PHP;
    }
    
    /**
     * Редактирует существующий сайт
     * 
     * @param int $siteId ID сайта
     * @param array $data Данные для обновления
     * @return bool Результат операции
     */
    public function updateSite($siteId, $data) {
        try {
            // Получаем текущие данные сайта
            $stmt = $this->db->prepare("SELECT * FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $currentSite = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$currentSite) {
                throw new Exception("Site with ID $siteId not found");
            }
            
            // Подготавливаем данные для обновления
            $updateData = [];
            $updateFields = [];
            
            foreach (['domain', 'title', 'active', 'ssl_enabled', 'cloudflare_enabled'] as $field) {
                if (isset($data[$field])) {
                    $updateFields[] = "$field = ?";
                    $updateData[] = $data[$field];
                }
            }
            
            if (empty($updateFields)) {
                // Нечего обновлять
                return true;
            }
            
            // Добавляем ID в конец массива для WHERE
            $updateData[] = $siteId;
            
            // Обновляем запись в БД
            $stmt = $this->db->prepare("UPDATE sites SET " . implode(', ', $updateFields) . " WHERE id = ?");
            $stmt->execute($updateData);
            
            $this->logger->log($siteId, 'site_updated', "Site updated: " . json_encode($data), 'success');
            
            // Обработка изменения домена, если домен был изменен
            if (isset($data['domain']) && $data['domain'] !== $currentSite['domain']) {
                $this->handleDomainChange($siteId, $currentSite['domain'], $data['domain']);
            }
            
            // Обработка изменения настроек Cloudflare
            if (isset($data['cloudflare_enabled']) && $data['cloudflare_enabled'] != $currentSite['cloudflare_enabled'] && $this->cloudflareManager !== null) {
                $domain = $data['domain'] ?? $currentSite['domain'];
                
                if ($data['cloudflare_enabled']) {
                    // Включение Cloudflare
                    try {
                        if ($this->cloudflareManager->addSite($domain)) {
                            $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare enabled for $domain", 'success');
                        } else {
                            $this->logger->log($siteId, 'cloudflare_setup', "Failed to enable CloudFlare for $domain", 'warning');
                        }
                    } catch (Exception $e) {
                        $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare error: " . $e->getMessage(), 'warning');
                    }
                } else {
                    // Отключение Cloudflare
                    try {
                        if ($this->cloudflareManager->removeSite($domain)) {
                            $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare disabled for $domain", 'success');
                        } else {
                            $this->logger->log($siteId, 'cloudflare_setup', "Failed to disable CloudFlare for $domain", 'warning');
                        }
                    } catch (Exception $e) {
                        $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare error: " . $e->getMessage(), 'warning');
                    }
                }
            }
            
            return true;
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'site_update', "Failed to update site: " . $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Обрабатывает изменение домена
     * 
     * @param int $siteId ID сайта
     * @param string $oldDomain Старый домен
     * @param string $newDomain Новый домен
     */
    private function handleDomainChange($siteId, $oldDomain, $newDomain) {
        try {
            // 1. Переименовываем директорию сайта
            $oldPath = SITES_BASE_PATH . '/' . $oldDomain;
            $newPath = SITES_BASE_PATH . '/' . $newDomain;
            
            if (file_exists($oldPath)) {
                if (file_exists($newPath)) {
                    throw new Exception("Directory for new domain already exists: $newPath");
                }
                
                if (!rename($oldPath, $newPath)) {
                    throw new Exception("Failed to rename directory from $oldPath to $newPath");
                }
                
                $this->logger->log($siteId, 'site_update', "Directory renamed from $oldPath to $newPath", 'success');
            } else {
                // Если старой директории нет, создаем новую
                if (!file_exists($newPath) && !mkdir($newPath, 0755, true)) {
                    throw new Exception("Failed to create directory for new domain: $newPath");
                }
                
                $this->logger->log($siteId, 'site_update', "Created new directory for changed domain: $newPath", 'success');
                
                // Настраиваем файлы в новой директории
                $this->setupSiteFiles($siteId, $newPath);
            }
            
            // 2. Обновляем конфигурацию Apache
            try {
                // Удаляем старый конфиг
                $this->apacheManager->removeConfig($oldDomain);
                $this->logger->log($siteId, 'apache_setup', "Old Apache config removed for $oldDomain", 'success');
                
                // Создаем новый конфиг
                $this->apacheManager->createConfig($newDomain, $newPath);
                $this->logger->log($siteId, 'apache_setup', "New Apache config created for $newDomain", 'success');
            } catch (Exception $e) {
                $this->logger->log($siteId, 'apache_setup', "Apache reconfiguration failed: " . $e->getMessage(), 'warning');
            }
            
            // 3. Обновляем настройки CloudFlare
            if ($this->cloudflareManager !== null) {
                try {
                    // Удаляем старый домен из CloudFlare
                    $this->cloudflareManager->removeSite($oldDomain);
                    $this->logger->log($siteId, 'cloudflare_setup', "Old domain removed from CloudFlare: $oldDomain", 'success');
                    
                    // Добавляем новый домен в CloudFlare, если включено
                    $stmt = $this->db->prepare("SELECT cloudflare_enabled FROM sites WHERE id = ?");
                    $stmt->execute([$siteId]);
                    $site = $stmt->fetch(PDO::FETCH_ASSOC);
                    
                    if ($site && $site['cloudflare_enabled']) {
                        if ($this->cloudflareManager->addSite($newDomain)) {
                            $this->logger->log($siteId, 'cloudflare_setup', "New domain added to CloudFlare: $newDomain", 'success');
                        } else {
                            $this->logger->log($siteId, 'cloudflare_setup', "Failed to add new domain to CloudFlare: $newDomain", 'warning');
                        }
                    }
                } catch (Exception $e) {
                    $this->logger->log($siteId, 'cloudflare_setup', "CloudFlare update failed: " . $e->getMessage(), 'warning');
                }
            }
            
        } catch (Exception $e) {
            $this->logger->log($siteId, 'site_update', "Domain change processing failed: " . $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Удаляет сайт
     * 
     * @param int $siteId ID сайта
     * @param bool $removeSiteFiles Удалять ли файлы сайта
     * @return bool Результат операции
     */
    public function deleteSite($siteId, $removeSiteFiles = false) {
        try {
            // Получаем данные сайта
            $stmt = $this->db->prepare("SELECT * FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            $site = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (!$site) {
                throw new Exception("Site with ID $siteId not found");
            }
            
            $domain = $site['domain'];
            $sitePath = SITES_BASE_PATH . '/' . $domain;
            
            $this->db->beginTransaction();
            
            // Удаляем связанные записи из базы данных
            $tables = ['pages', 'components', 'redirects', 'settings'];
            foreach ($tables as $table) {
                $stmt = $this->db->prepare("DELETE FROM $table WHERE site_id = ?");
                $stmt->execute([$siteId]);
            }
            
            // Удаляем сам сайт
            $stmt = $this->db->prepare("DELETE FROM sites WHERE id = ?");
            $stmt->execute([$siteId]);
            
            $this->db->commit();
            
            $this->logger->log($siteId, 'site_deleted', "Site $domain deleted from database", 'success');
            
            // Удаляем Apache конфигурацию
            try {
                $this->apacheManager->removeConfig($domain);
                $this->logger->log($siteId, 'apache_setup', "Apache config removed for $domain", 'success');
            } catch (Exception $e) {
                $this->logger->log($siteId, 'apache_setup', "Failed to remove Apache config: " . $e->getMessage(), 'warning');
            }
            
            // Удаляем из CloudFlare
            if ($site['cloudflare_enabled'] && $this->cloudflareManager !== null) {
                try {
                    $this->cloudflareManager->removeSite($domain);
                    $this->logger->log($siteId, 'cloudflare_setup', "Domain removed from CloudFlare: $domain", 'success');
                } catch (Exception $e) {
                    $this->logger->log($siteId, 'cloudflare_setup', "Failed to remove from CloudFlare: " . $e->getMessage(), 'warning');
                }
            }
            
            // Удаляем файлы сайта, если требуется
            if ($removeSiteFiles && file_exists($sitePath)) {
                $this->removeSiteDirectory($sitePath);
                $this->logger->log($siteId, 'site_deleted', "Site files removed: $sitePath", 'success');
            }
            
            return true;
            
        } catch (Exception $e) {
            if ($this->db->inTransaction()) {
                $this->db->rollBack();
            }
            $this->logger->log($siteId, 'site_deleted', "Failed to delete site: " . $e->getMessage(), 'error');
            throw $e;
        }
    }
    
    /**
     * Рекурсивно удаляет директорию и все ее содержимое
     * 
     * @param string $dir Путь к директории
     * @return bool Результат операции
     */
    private function removeSiteDirectory($dir) {
        if (!file_exists($dir)) {
            return true;
        }
        
        $files = array_diff(scandir($dir), ['.', '..']);
        
        foreach ($files as $file) {
            $path = $dir . '/' . $file;
            
            if (is_dir($path)) {
                $this->removeSiteDirectory($path);
            } else {
                unlink($path);
            }
        }
        
        return rmdir($dir);
    }
}