<?php
// includes/SystemLogger.php
class SystemLogger {
    private $db;
    
    public function __construct(PDO $db) {
        $this->db = $db;
    }
    
    /**
     * Записывает лог в систему
     */
    public function log($siteId, $action, $description, $status = 'info') {
        try {
            // Проверяем существование таблицы логов
            $this->ensureLogTableExists();
            
            // Записываем лог в базу данных
            $stmt = $this->db->prepare("
                INSERT INTO system_logs (site_id, action, description, status)
                VALUES (?, ?, ?, ?)
            ");
            $stmt->execute([$siteId, $action, $description, $status]);
            
            // Дополнительно записываем в файл для надежности
            $this->logToFile($siteId, $action, $description, $status);
            
            return true;
        } catch (Exception $e) {
            // В случае ошибки пишем в обычный лог
            error_log("SystemLogger error: " . $e->getMessage());
            // И пытаемся записать в файл
            $this->logToFile(
                $siteId,
                'logger_error',
                "Logger error: " . $e->getMessage(),
                'error'
            );
            return false;
        }
    }
    
    /**
     * Создает таблицу логов, если она не существует
     */
    private function ensureLogTableExists() {
        try {
            $tableExists = $this->db->query("SHOW TABLES LIKE 'system_logs'")->rowCount() > 0;
            
            if (!$tableExists) {
                $this->db->exec("
                    CREATE TABLE system_logs (
                        id INT AUTO_INCREMENT PRIMARY KEY,
                        site_id INT NULL,
                        action VARCHAR(255) NOT NULL,
                        description TEXT,
                        status ENUM('success', 'error', 'warning', 'info') NOT NULL DEFAULT 'info',
                        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                        INDEX (site_id),
                        INDEX (action),
                        INDEX (status)
                    )
                ");
            }
        } catch (Exception $e) {
            error_log("Failed to create system_logs table: " . $e->getMessage());
        }
    }
    
    /**
     * Записывает лог в файл
     */
    private function logToFile($siteId, $action, $description, $status) {
        $logDir = __DIR__ . '/../admin/logs';
        
        // Проверяем/создаем директорию логов
        if (!is_dir($logDir)) {
            if (!mkdir($logDir, 0777, true)) {
                error_log("Failed to create log directory: $logDir");
                return false;
            }
        }
        
        $logFile = $logDir . '/system.log';
        $timestamp = date('Y-m-d H:i:s');
        $siteId = $siteId ?: 'none';
        
        $logEntry = "[{$timestamp}] [{$status}] [Site: {$siteId}] [{$action}] {$description}" . PHP_EOL;
        
        return file_put_contents($logFile, $logEntry, FILE_APPEND);
    }
}