<?php
// includes/TemplateProcessor.php
class TemplateProcessor {
    private $db;
    private $contentManager;
    
    public function __construct(PDO $db) {
        $this->db = $db;
        $this->contentManager = new ContentManager($db);
    }
    
    /**
     * Process page with components and variables
     */
    public function processPage($siteId, $page, $domain) {
        // 1. Get site information
        $stmt = $this->db->prepare("SELECT * FROM sites WHERE id = ?");
        $stmt->execute([$siteId]);
        $site = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$site) {
            throw new Exception("Site not found");
        }
        
        // 2. Get components
        $components = $this->contentManager->getComponents($siteId);
        $header = $this->findComponent($components, 'header');
        $footer = $this->findComponent($components, 'footer');
        $sidebar = $this->findComponent($components, 'sidebar');
        
        // 3. Generate menu
        $menuHtml = $this->contentManager->generateMenu($siteId, $page['slug']);
        
        // 4. Prepare variables
        $variables = [
            '{site_title}' => $site['title'],
            '{site_name}' => $site['title'],
            '{site_url}' => $domain,
            '{page_title}' => $page['title'],
            '{page_h1}' => $page['h1'] ?? $page['title'],
            '{page_description}' => $page['meta_description'] ?? '',
            '{menu}' => $menuHtml,
            '{navigation}' => $menuHtml,
            '{current_year}' => date('Y'),
            '{header}' => $header ? $this->processContent($header['content'], $variables) : '',
            '{footer}' => $footer ? $this->processContent($footer['content'], $variables) : '',
            '{sidebar}' => $sidebar ? $this->processContent($sidebar['content'], $variables) : ''
        ];
        
        // 5. Process page content
        $pageContent = $this->processContent($page['content'], $variables);
        
        // 6. Return processed data
        return [
            'site' => $site,
            'page' => $page,
            'content' => $pageContent,
            'header' => $variables['{header}'],
            'footer' => $variables['{footer}'],
            'sidebar' => $variables['{sidebar}'],
            'meta_title' => $page['meta_title'] ?? $page['title'],
            'meta_description' => $page['meta_description'] ?? ''
        ];
    }
    
    /**
     * Find component by type
     */
    private function findComponent($components, $type) {
        foreach ($components as $component) {
            if ($component['type'] === $type) {
                return $component;
            }
        }
        return null;
    }
    
    /**
     * Process content by replacing variables
     */
    private function processContent($content, $variables) {
        return str_replace(
            array_keys($variables),
            array_values($variables),
            $content
        );
    }
}