<?php
// templates/index.template.php
/**
 * Main template file for all PBN sites
 * This file should be copied to each site directory during site creation
 */

// Load configuration
require_once 'config.php';

// Initialize DB connection
$db = getDB();

// Get current site
$stmt = $db->prepare("SELECT * FROM sites WHERE id = ?");
$stmt->execute([SITE_ID]);
$site = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$site || !$site['active']) {
    header("HTTP/1.0 404 Not Found");
    echo "Site not found or inactive";
    exit;
}

// Include required classes from admin
require_once '/var/www/www-root/data/www/pbnstat.ru/pbns/includes/ContentManager.php';
require_once '/var/www/www-root/data/www/pbnstat.ru/pbns/includes/TemplateProcessor.php';

// Initialize managers
$contentManager = new ContentManager($db);
$templateProcessor = new TemplateProcessor($db);

// Get requested URL
$requestUri = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
$slug = trim($requestUri, '/');

// Handle root URL
if (empty($slug)) {
    $slug = 'home';
}

// Get page by slug
$page = $contentManager->getPageBySlug(SITE_ID, $slug);

// If page not found, check redirects
if (!$page) {
    $stmt = $db->prepare("
        SELECT target_url, redirect_type 
        FROM redirects 
        WHERE site_id = ? AND source_url = ? AND is_active = 1
    ");
    $stmt->execute([SITE_ID, $requestUri]);
    $redirect = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($redirect) {
        header("Location: {$redirect['target_url']}", true, $redirect['redirect_type']);
        exit;
    }
    
    // If no redirect found, show 404 page
    $page = $contentManager->getPageBySlug(SITE_ID, '404');
    if (!$page) {
        // If no custom 404 page, show default
        header("HTTP/1.0 404 Not Found");
        echo "<h1>Page Not Found</h1>";
        echo "<p>The requested page could not be found.</p>";
        exit;
    }
}

// Process page template
$data = $templateProcessor->processPage(SITE_ID, $page, $_SERVER['HTTP_HOST']);

// Output final HTML
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($data['meta_title']); ?></title>
    <meta name="description" content="<?php echo htmlspecialchars($data['meta_description']); ?>">
    <link rel="stylesheet" href="/css/style.css">
    <?php
    // Get site settings for custom styles and scripts
    $stmt = $db->prepare("SELECT key_name, value FROM site_settings WHERE site_id = ? AND key_name LIKE 'head_%'");
    $stmt->execute([SITE_ID]);
    while ($setting = $stmt->fetch(PDO::FETCH_ASSOC)) {
        echo $setting['value'] . "\n";
    }
    ?>
</head>
<body>
    <div class="site-container">
        <header class="site-header">
            <?php echo $data['header']; ?>
        </header>
        
        <main class="site-content">
            <?php if (!empty($data['sidebar'])): ?>
            <div class="content-with-sidebar">
                <div class="main-content">
                    <?php echo $data['content']; ?>
                </div>
                <aside class="sidebar">
                    <?php echo $data['sidebar']; ?>
                </aside>
            </div>
            <?php else: ?>
            <div class="main-content-full">
                <?php echo $data['content']; ?>
            </div>
            <?php endif; ?>
        </main>
        
        <footer class="site-footer">
            <?php echo $data['footer']; ?>
        </footer>
    </div>
    
    <?php
    // Get site settings for custom footer scripts
    $stmt = $db->prepare("SELECT value FROM site_settings WHERE site_id = ? AND key_name = 'footer_scripts'");
    $stmt->execute([SITE_ID]);
    $footerScripts = $stmt->fetchColumn();
    if ($footerScripts) {
        echo $footerScripts;
    }
    ?>
</body>
</html>