<?php
/**
 * Web Archive HTML/CSS Extractor
 * 
 * This tool extracts HTML and associated CSS from Internet Archive's Wayback Machine
 * based on specific XPath selectors (like headers and footers).
 */

// Error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Function to extract HTML content based on XPath
function extractContent($url, $xpath) {
    // Load the HTML using cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    
    $html = curl_exec($ch);
    
    if (curl_errno($ch)) {
        return "Error fetching URL: " . curl_error($ch);
    }
    
    curl_close($ch);
    
    // Create DOM document and XPath
    $dom = new DOMDocument();
    @$dom->loadHTML($html);
    $xpathObj = new DOMXPath($dom);
    
    // Get content based on XPath
    $elements = $xpathObj->query($xpath);
    
    if ($elements->length === 0) {
        return "No elements found matching the XPath: $xpath";
    }
    
    // Extract HTML for matched elements
    $result = '';
    foreach ($elements as $element) {
        $elementDom = new DOMDocument();
        $elementDom->formatOutput = true;
        $node = $elementDom->importNode($element, true);
        $elementDom->appendChild($node);
        $result .= $elementDom->saveHTML();
    }
    
    return $result;
}

// Function to extract all CSS from a page
function extractCSS($url) {
    // Load the HTML using cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    
    $html = curl_exec($ch);
    
    if (curl_errno($ch)) {
        return "Error fetching URL: " . curl_error($ch);
    }
    
    curl_close($ch);
    
    // Create DOM document
    $dom = new DOMDocument();
    @$dom->loadHTML($html);
    
    // Find all CSS (both inline and external)
    $cssContent = '';
    
    // Get inline styles
    $styles = $dom->getElementsByTagName('style');
    foreach ($styles as $style) {
        $cssContent .= $style->nodeValue . "\n";
    }
    
    // Get external stylesheets
    $links = $dom->getElementsByTagName('link');
    foreach ($links as $link) {
        if ($link->getAttribute('rel') === 'stylesheet') {
            $cssUrl = $link->getAttribute('href');
            
            // Handle relative URLs
            if (strpos($cssUrl, 'http') !== 0) {
                // Parse the original URL to get the base
                $parsedUrl = parse_url($url);
                $base = $parsedUrl['scheme'] . '://' . $parsedUrl['host'];
                
                // Check if CSS URL starts with / or not
                if (strpos($cssUrl, '/') === 0) {
                    $cssUrl = $base . $cssUrl;
                } else {
                    // Get the directory part of the path
                    $dir = dirname($parsedUrl['path']);
                    $cssUrl = $base . $dir . '/' . $cssUrl;
                }
            }
            
            // Fetch the CSS content
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $cssUrl);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
            $css = curl_exec($ch);
            curl_close($ch);
            
            if ($css) {
                $cssContent .= "/* CSS from $cssUrl */\n" . $css . "\n";
            }
        }
    }
    
    return $cssContent;
}

// Handle form submission
$html = '';
$css = '';
$url = '';
$xpath = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $url = isset($_POST['url']) ? $_POST['url'] : '';
    $xpath = isset($_POST['xpath']) ? $_POST['xpath'] : '';
    
    if (!empty($url)) {
        if (!empty($xpath)) {
            $html = extractContent($url, $xpath);
        }
        $css = extractCSS($url);
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Web Archive HTML/CSS Extractor</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            color: #333;
        }
        h1 {
            color: #2c3e50;
        }
        form {
            margin-bottom: 20px;
            padding: 20px;
            background-color: #f5f5f5;
            border-radius: 5px;
        }
        label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }
        input[type="text"] {
            width: 100%;
            padding: 8px;
            margin-bottom: 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        button {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 10px 15px;
            cursor: pointer;
            border-radius: 4px;
        }
        button:hover {
            background-color: #2980b9;
        }
        .output {
            margin-top: 20px;
        }
        .code-container {
            background-color: #f8f8f8;
            border: 1px solid #ddd;
            border-radius: 4px;
            padding: 15px;
            margin-bottom: 20px;
            overflow: auto;
        }
        pre {
            margin: 0;
            white-space: pre-wrap;
            font-family: monospace;
        }
        .copy-btn {
            display: block;
            margin: 10px 0;
            background-color: #27ae60;
        }
        .copy-btn:hover {
            background-color: #219653;
        }
        .examples {
            margin-top: 20px;
            font-size: 0.9em;
            color: #555;
        }
    </style>
</head>
<body>
    <h1>Web Archive HTML/CSS Extractor</h1>
    
    <form method="post" action="">
        <div>
            <label for="url">Web Archive URL:</label>
            <input type="text" id="url" name="url" value="<?php echo htmlspecialchars($url); ?>" placeholder="https://web.archive.org/web/20190826011058/http://ukuzmicha.ru//" required>
        </div>
        
        <div>
            <label for="xpath">XPath Selector:</label>
            <input type="text" id="xpath" name="xpath" value="<?php echo htmlspecialchars($xpath); ?>" placeholder="//header or //footer or //div[@class='header']">
        </div>
        
        <button type="submit">Extract Content</button>
    </form>
    
    <div class="examples">
        <p><strong>Example XPath expressions:</strong></p>
        <ul>
            <li><code>//header</code> - Selects all header elements</li>
            <li><code>//footer</code> - Selects all footer elements</li>
            <li><code>//div[@class='header']</code> - Selects div with class "header"</li>
            <li><code>//nav</code> - Selects all navigation elements</li>
            <li>Leave XPath empty to only extract CSS</li>
        </ul>
    </div>
    
    <?php if ($_SERVER['REQUEST_METHOD'] === 'POST' && !empty($url)): ?>
        <div class="output">
            <?php if (!empty($html)): ?>
                <h2>Extracted HTML</h2>
                <div class="code-container">
                    <pre id="html-output"><?php echo htmlspecialchars($html); ?></pre>
                </div>
                <button class="copy-btn" onclick="copyToClipboard('html-output')">Copy HTML</button>
            <?php endif; ?>
            
            <?php if (!empty($css)): ?>
                <h2>Extracted CSS</h2>
                <div class="code-container">
                    <pre id="css-output"><?php echo htmlspecialchars($css); ?></pre>
                </div>
                <button class="copy-btn" onclick="copyToClipboard('css-output')">Copy CSS</button>
            <?php endif; ?>
        </div>
        
        <script>
            function copyToClipboard(elementId) {
                const element = document.getElementById(elementId);
                const text = element.textContent;
                
                const textarea = document.createElement('textarea');
                textarea.value = text;
                document.body.appendChild(textarea);
                textarea.select();
                document.execCommand('copy');
                document.body.removeChild(textarea);
                
                alert('Copied to clipboard!');
            }
        </script>
    <?php endif; ?>
</body>
</html>