<?php
/**
 * Web Archive HTML/CSS Extractor with UTF-8 support and variable replacement.
 * 
 * This tool extracts HTML and associated CSS from Internet Archive's Wayback Machine
 * and replaces Web Archive URLs with predefined variables, handling UTF-8 encoding properly.
 */

// Ensure proper UTF-8 encoding
header('Content-Type: text/html; charset=UTF-8');

// Predefined Variables
$variables = [
    '{site_title}' => 'My Site Title',
    '{site_name}' => 'My Site Name',
    '{site_url}' => 'https://www.mysite.com',
    '{menu}' => '<ul><li>Home</li><li>About</li><li>Contact</li></ul>',
    '{current_year}' => date('Y'),
    '{site_logo}' => '<img src="https://www.mysite.com/logo.png" alt="Site Logo">',
    '{site_number}' => '12345',
    '{site_address}' => '1234 Some St, City, Country'
];

// Function to extract HTML content based on XPath
function extractContent($url, $xpath) {
    global $variables;

    // Load the HTML using cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    
    $html = curl_exec($ch);
    
    if (curl_errno($ch)) {
        return "Error fetching URL: " . curl_error($ch);
    }
    
    curl_close($ch);
    
    // Create DOM document and XPath
    $dom = new DOMDocument();
    @$dom->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'));  // Convert to UTF-8 encoding
    $xpathObj = new DOMXPath($dom);
    
    // Get content based on XPath
    $elements = $xpathObj->query($xpath);
    
    if ($elements->length === 0) {
        return "No elements found matching the XPath: $xpath";
    }
    
    // Extract HTML for matched elements
    $result = '';
    foreach ($elements as $element) {
        $elementDom = new DOMDocument();
        $elementDom->formatOutput = true;
        $node = $elementDom->importNode($element, true);
        $elementDom->appendChild($node);
        $result .= $elementDom->saveHTML();
    }
    
    // Replace the variables in the extracted content
    foreach ($variables as $key => $value) {
        $result = str_replace($key, $value, $result);
    }

    // Replace Web Archive URLs
    $result = replaceArchiveUrls($result);
    
    return $result;
}

// Function to replace Web Archive URLs with the site URL
function replaceArchiveUrls($htmlContent) {
    // Regular expression to find URLs like https://web.archive.org/web/some-numbers/some-website-url/
    $pattern = '/https:\/\/web\.archive\.org\/web\/\d{14}\/(http[s]?:\/\/[^"]+)/i';
    
    // Replace the archive URL with {site_url}
    $replacement = '{site_url}'; // This replaces with the predefined site URL variable
    
    // Perform the replacement
    return preg_replace($pattern, $replacement, $htmlContent);
}

// Function to extract all CSS from a page
function extractCSS($url) {
    global $variables;

    // Load the HTML using cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    
    $html = curl_exec($ch);
    
    if (curl_errno($ch)) {
        return "Error fetching URL: " . curl_error($ch);
    }
    
    curl_close($ch);
    
    // Create DOM document
    $dom = new DOMDocument();
    @$dom->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'));  // Convert to UTF-8 encoding
    
    // Find all CSS (both inline and external)
    $cssContent = '';
    
    // Get inline styles
    $styles = $dom->getElementsByTagName('style');
    foreach ($styles as $style) {
        $cssContent .= $style->nodeValue . "\n";
    }
    
    // Get external stylesheets
    $links = $dom->getElementsByTagName('link');
    foreach ($links as $link) {
        if ($link->getAttribute('rel') === 'stylesheet') {
            $cssUrl = $link->getAttribute('href');
            
            // Handle relative URLs
            if (strpos($cssUrl, 'http') !== 0) {
                // Parse the original URL to get the base
                $parsedUrl = parse_url($url);
                $base = $parsedUrl['scheme'] . '://' . $parsedUrl['host'];
                
                // Check if CSS URL starts with / or not
                if (strpos($cssUrl, '/') === 0) {
                    $cssUrl = $base . $cssUrl;
                } else {
                    // Get the directory part of the path
                    $dir = dirname($parsedUrl['path']);
                    $cssUrl = $base . $dir . '/' . $cssUrl;
                }
            }
            
            // Fetch the CSS content
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $cssUrl);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
            $css = curl_exec($ch);
            curl_close($ch);
            
            if ($css) {
                $cssContent .= "/* CSS from $cssUrl */\n" . $css . "\n";
            }
        }
    }
    
    return $cssContent;
}

// Handle form submission
$html = '';
$css = '';
$url = '';
$xpath = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $url = isset($_POST['url']) ? $_POST['url'] : '';
    $xpath = isset($_POST['xpath']) ? $_POST['xpath'] : '';
    
    if (!empty($url)) {
        if (!empty($xpath)) {
            $html = extractContent($url, $xpath);
        }
        $css = extractCSS($url);
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Web Archive HTML/CSS Extractor</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            color: #333;
        }
        h1 {
            color: #2c3e50;
        }
        form {
            margin-bottom: 20px;
            padding: 20px;
            background-color: #f5f5f5;
            border-radius: 5px;
        }
        label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }
        input[type="text"] {
            width: 100%;
            padding: 8px;
            margin-bottom: 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        button {
            background-color: #3498db;
            color: white;
            border: none;
            padding: 10px 15px;
            cursor: pointer;
            border-radius: 4px;
        }
        button:hover {
            background-color: #2980b9;
        }
        .output {
            margin-top: 20px;
        }
        .code-container {
            background-color: #f8f8f8;
            border: 1px solid #ddd;
            border-radius: 4px;
            padding: 15px;
            margin-bottom: 20px;
            overflow: auto;
        }
        pre {
            margin: 0;
            white-space: pre-wrap;
            font-family: monospace;
        }
        .copy-btn {
            display: block;
            margin: 10px 0;
            background-color: #27ae60;
        }
        .copy-btn:hover {
            background-color: #219653;
        }
        .examples {
            margin-top: 30px;
        }
    </style>
</head>
<body>
    <h1>Web Archive HTML/CSS Extractor</h1>
    
    <form action="" method="POST">
        <label for="url">Enter URL:</label>
        <input type="text" name="url" id="url" value="<?php echo htmlspecialchars($url); ?>" required>
        
        <label for="xpath">Enter XPath (optional):</label>
        <input type="text" name="xpath" id="xpath" value="<?php echo htmlspecialchars($xpath); ?>">
        
        <button type="submit">Extract HTML & CSS</button>
    </form>

    <div class="output">
        <h3>Extracted HTML Content</h3>
        <div class="code-container">
            <pre><?php echo htmlspecialchars($html); ?></pre>
        </div>
        
        <button class="copy-btn" onclick="copyText('html')">Copy HTML Content</button>
        
        <h3>Extracted CSS</h3>
        <div class="code-container">
            <pre><?php echo htmlspecialchars($css); ?></pre>
        </div>
        
        <button class="copy-btn" onclick="copyText('css')">Copy CSS Content</button>
    </div>

    <div class="examples">
        <h3>Variable Examples</h3>
        <p><strong>{site_title}:</strong> My Site Title</p>
        <p><strong>{site_name}:</strong> My Site Name</p>
        <p><strong>{site_url}:</strong> https://www.mysite.com</p>
        <p><strong>{menu}:</strong> <ul><li>Home</li><li>About</li><li>Contact</li></ul></p>
        <p><strong>{current_year}:</strong> <?php echo date('Y'); ?></p>
        <p><strong>{site_logo}:</strong> <img src="https://www.mysite.com/logo.png" alt="Site Logo"></p>
        <p><strong>{site_number}:</strong> 12345</p>
        <p><strong>{site_address}:</strong> 1234 Some St, City, Country</p>
    </div>

    <script>
        function copyText(type) {
            let text;
            if (type === 'html') {
                text = document.querySelector('pre').textContent;
            } else if (type === 'css') {
                text = document.querySelectorAll('pre')[1].textContent;
            }
            navigator.clipboard.writeText(text).then(function() {
                alert("Copied to clipboard!");
            }, function(err) {
                console.error("Could not copy text: ", err);
            });
        }
    </script>
</body>
</html>
