<?php
/**
 * Web Archive HTML/CSS Extractor with UTF-8 support, variable replacement, and image downloading.
 */

// Ensure proper UTF-8 encoding
header('Content-Type: text/html; charset=UTF-8');

// Predefined Variables
$variables = [
    '{site_title}' => 'My Site Title',
    '{site_name}' => 'My Site Name',
    '{site_url}' => 'https://www.mysite.com',
    '{menu}' => '<ul><li>Home</li><li>About</li><li>Contact</li></ul>',
    '{current_year}' => date('Y'),
    '{site_logo}' => '<img src="https://www.mysite.com/logo.png" alt="Site Logo">',
    '{site_number}' => '12345',
    '{site_address}' => '1234 Some St, City, Country'
];

// Function to extract HTML content based on XPath
function extractContent($url, $xpath) {
    global $variables;

    // Load the HTML using cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    
    $html = curl_exec($ch);
    
    if (curl_errno($ch)) {
        return "Error fetching URL: " . curl_error($ch);
    }
    
    curl_close($ch);
    
    // Create DOM document and XPath
    $dom = new DOMDocument();
    @$dom->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'));  // Convert to UTF-8 encoding
    $xpathObj = new DOMXPath($dom);
    
    // Get content based on XPath
    $elements = $xpathObj->query($xpath);
    
    if ($elements->length === 0) {
        return "No elements found matching the XPath: $xpath";
    }
    
    // Extract HTML for matched elements
    $result = '';
    foreach ($elements as $element) {
        $elementDom = new DOMDocument();
        $elementDom->formatOutput = true;
        $node = $elementDom->importNode($element, true);
        $elementDom->appendChild($node);
        $result .= $elementDom->saveHTML();
    }
    
    // Replace the variables in the extracted content
    foreach ($variables as $key => $value) {
        $result = str_replace($key, $value, $result);
    }

    // Replace Web Archive URLs
    $result = replaceArchiveUrls($result);
    
    // Download images (logos and others) in the extracted content
    $result = downloadImages($result);
    
    return $result;
}

// Function to replace Web Archive URLs with the site URL
function replaceArchiveUrls($htmlContent) {
    // Regular expression to find URLs like https://web.archive.org/web/some-numbers/some-website-url/
    $pattern = '/https:\/\/web\.archive\.org\/web\/\d{14}\/(http[s]?:\/\/[^"]+)/i';
    
    // Replace the archive URL with {site_url}
    $replacement = '{site_url}'; // This replaces with the predefined site URL variable
    
    // Perform the replacement
    return preg_replace($pattern, $replacement, $htmlContent);
}

// Function to download images (logos and other images) referenced in the HTML content
function downloadImages($htmlContent) {
    preg_match_all('/<img[^>]+src="([^"]+)"/i', $htmlContent, $matches);

    $downloadedImages = [];
    foreach ($matches[1] as $imageUrl) {
        // Skip if the image URL is already a local image (don't download it again)
        if (strpos($imageUrl, '{site_url}') !== false) {
            continue;
        }

        // Download image
        $imageContent = file_get_contents($imageUrl);
        if ($imageContent) {
            // Get image file name from the URL
            $imagePath = parse_url($imageUrl, PHP_URL_PATH);
            $imageName = basename($imagePath);
            $imageDir = 'images/'; // Folder where images will be saved
            if (!is_dir($imageDir)) {
                mkdir($imageDir, 0777, true);
            }

            // Save the image locally
            $imageFilePath = $imageDir . $imageName;
            file_put_contents($imageFilePath, $imageContent);
            
            // Replace the image URL with the local path
            $localImagePath = '{site_url}/' . $imageFilePath;
            $htmlContent = str_replace($imageUrl, $localImagePath, $htmlContent);
            $downloadedImages[] = $imageFilePath; // Keep track of downloaded images
        }
    }

    // Optionally return a list of downloaded images
    return $htmlContent;
}

// Function to extract all CSS from a page
function extractCSS($url) {
    global $variables;

    // Load the HTML using cURL
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36');
    
    $html = curl_exec($ch);
    
    if (curl_errno($ch)) {
        return "Error fetching URL: " . curl_error($ch);
    }
    
    curl_close($ch);
    
    // Create DOM document
    $dom = new DOMDocument();
    @$dom->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'));  // Convert to UTF-8 encoding
    
    // Find all CSS (both inline and external)
    $cssContent = '';
    
    // Get inline styles
    $styles = $dom->getElementsByTagName('style');
    foreach ($styles as $style) {
        $cssContent .= $style->nodeValue . "\n";
    }
    
    // Get external stylesheets
    $links = $dom->getElementsByTagName('link');
    foreach ($links as $link) {
        if ($link->getAttribute('rel') === 'stylesheet') {
            $cssUrl = $link->getAttribute('href');
            
            // Handle relative URLs
            if (strpos($cssUrl, 'http') !== 0) {
                // Parse the original URL to get the base
                $parsedUrl = parse_url($url);
                $base = $parsedUrl['scheme'] . '://' . $parsedUrl['host'];
                
                // Check if CSS URL starts with / or not
                if (strpos($cssUrl, '/') === 0) {
                    $cssUrl = $base . $cssUrl;
                } else {
                    // Get the directory part of the path
                    $dir = dirname($parsedUrl['path']);
                    $cssUrl = $base . $dir . '/' . $cssUrl;
                }
            }
            
            // Fetch the CSS content
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $cssUrl);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
            $css = curl_exec($ch);
            curl_close($ch);
            
            if ($css) {
                $cssContent .= "/* CSS from $cssUrl */\n" . $css . "\n";
            }
        }
    }
    
    return $cssContent;
}

// Handle form submission
$html = '';
$css = '';
$url = '';
$xpath = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $url = isset($_POST['url']) ? $_POST['url'] : '';
    $xpath = isset($_POST['xpath']) ? $_POST['xpath'] : '';
    
    if (!empty($url)) {
        if (!empty($xpath)) {
            $html = extractContent($url, $xpath);
        }
        $css = extractCSS($url);
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Web Archive HTML/CSS Extractor</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            color: #333;
        }
        h1 {
            color: #2c3e50;
        }
        form {
            margin-bottom: 20px;
        }
        input[type="text"], button {
            padding: 8px;
            margin: 5px 0;
            font-size: 14px;
        }
        button {
            background-color: #2980b9;
            color: white;
            border: none;
        }
        button:hover {
            background-color: #3498db;
        }
        .output {
            margin-top: 20px;
        }
        .output pre {
            white-space: pre-wrap;
            word-wrap: break-word;
        }
        .copy-btn {
            padding: 5px 10px;
            background-color: #2ecc71;
            color: white;
            border: none;
            cursor: pointer;
        }
        .copy-btn:hover {
            background-color: #27ae60;
        }
    </style>
</head>
<body>
    <h1>Web Archive HTML/CSS Extractor</h1>
    
    <form action="" method="POST">
        <label for="url">Enter URL:</label>
        <input type="text" name="url" id="url" value="<?php echo htmlspecialchars($url); ?>" required>
        
        <label for="xpath">Enter XPath (optional):</label>
        <input type="text" name="xpath" id="xpath" value="<?php echo htmlspecialchars($xpath); ?>">
        
        <button type="submit">Extract HTML & CSS</button>
    </form>

    <div class="output">
        <h3>Extracted HTML Content</h3>
        <div class="code-container">
            <pre><?php echo htmlspecialchars($html); ?></pre>
        </div>
        
        <button class="copy-btn" onclick="copyText('html')">Copy HTML Content</button>
        
        <h3>Extracted CSS</h3>
        <div class="code-container">
            <pre><?php echo htmlspecialchars($css); ?></pre>
        </div>
        
        <button class="copy-btn" onclick="copyText('css')">Copy CSS Content</button>
    </div>

    <script>
        function copyText(type) {
            let text;
            if (type === 'html') {
                text = document.querySelector('pre').textContent;
            } else if (type === 'css') {
                text = document.querySelectorAll('pre')[1].textContent;
            }
            navigator.clipboard.writeText(text).then(function() {
                alert("Copied to clipboard!");
            }, function(err) {
                console.error("Could not copy text: ", err);
            });
        }
    </script>
</body>
</html>
